Class: Google::Apis::HealthcareV1::AttributeDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

A client-defined consent attribute.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttributeDefinition

Returns a new instance of AttributeDefinition.



472
473
474
# File 'lib/google/apis/healthcare_v1/classes.rb', line 472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_valuesArray<String>

Required. Possible values for the attribute. The number of allowed values must not exceed 500. An empty list is invalid. The list can only be expanded after creation. Corresponds to the JSON property allowedValues

Returns:

  • (Array<String>)


438
439
440
# File 'lib/google/apis/healthcare_v1/classes.rb', line 438

def allowed_values
  @allowed_values
end

#categoryString

Required. The category of the attribute. The value of this field cannot be changed after creation. Corresponds to the JSON property category

Returns:

  • (String)


444
445
446
# File 'lib/google/apis/healthcare_v1/classes.rb', line 444

def category
  @category
end

Optional. Default values of the attribute in Consents. If no default values are specified, it defaults to an empty value. Corresponds to the JSON property consentDefaultValues

Returns:

  • (Array<String>)


450
451
452
# File 'lib/google/apis/healthcare_v1/classes.rb', line 450

def consent_default_values
  @consent_default_values
end

#data_mapping_default_valueString

Optional. Default value of the attribute in User data mappings. If no default value is specified, it defaults to an empty value. This field is only applicable to attributes of the category RESOURCE. Corresponds to the JSON property dataMappingDefaultValue

Returns:

  • (String)


457
458
459
# File 'lib/google/apis/healthcare_v1/classes.rb', line 457

def data_mapping_default_value
  @data_mapping_default_value
end

#descriptionString

Optional. A description of the attribute. Corresponds to the JSON property description

Returns:

  • (String)


462
463
464
# File 'lib/google/apis/healthcare_v1/classes.rb', line 462

def description
  @description
end

#nameString

Identifier. Resource name of the Attribute definition, of the form projects/ project_id/locations/location_id/datasets/dataset_id/consentStores/ consent_store_id/attributeDefinitions/attribute_definition_id`. Cannot be changed after creation. Corresponds to the JSON propertyname`

Returns:

  • (String)


470
471
472
# File 'lib/google/apis/healthcare_v1/classes.rb', line 470

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



477
478
479
480
481
482
483
484
# File 'lib/google/apis/healthcare_v1/classes.rb', line 477

def update!(**args)
  @allowed_values = args[:allowed_values] if args.key?(:allowed_values)
  @category = args[:category] if args.key?(:category)
  @consent_default_values = args[:consent_default_values] if args.key?(:consent_default_values)
  @data_mapping_default_value = args[:data_mapping_default_value] if args.key?(:data_mapping_default_value)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
end