Class: Google::Apis::HealthcareV1::CheckDataAccessRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::CheckDataAccessRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Checks if a particular data_id of a User data mapping in the given consent store is consented for a given use.
Instance Attribute Summary collapse
-
#consent_list ⇒ Google::Apis::HealthcareV1::ConsentList
List of resource names of Consent resources.
-
#data_id ⇒ String
Required.
-
#request_attributes ⇒ Hash<String,String>
The values of request attributes associated with this access request.
-
#response_view ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckDataAccessRequest
constructor
A new instance of CheckDataAccessRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckDataAccessRequest
Returns a new instance of CheckDataAccessRequest.
852 853 854 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 852 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_list ⇒ Google::Apis::HealthcareV1::ConsentList
List of resource names of Consent resources.
Corresponds to the JSON property consentList
833 834 835 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 833 def @consent_list end |
#data_id ⇒ String
Required. The unique identifier of the resource to check access for. This
identifier must correspond to a User data mapping in the given consent store.
Corresponds to the JSON property dataId
839 840 841 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 839 def data_id @data_id end |
#request_attributes ⇒ Hash<String,String>
The values of request attributes associated with this access request.
Corresponds to the JSON property requestAttributes
844 845 846 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 844 def request_attributes @request_attributes end |
#response_view ⇒ String
Optional. The view for CheckDataAccessResponse. If unspecified, defaults to
BASIC and returns consented as TRUE or FALSE.
Corresponds to the JSON property responseView
850 851 852 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 850 def response_view @response_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
857 858 859 860 861 862 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 857 def update!(**args) @consent_list = args[:consent_list] if args.key?(:consent_list) @data_id = args[:data_id] if args.key?(:data_id) @request_attributes = args[:request_attributes] if args.key?(:request_attributes) @response_view = args[:response_view] if args.key?(:response_view) end |