Class: Google::Apis::HealthcareV1::CheckDataAccessResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Checks if a particular data_id of a User data mapping in the given consent store is consented for a given use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckDataAccessResponse

Returns a new instance of CheckDataAccessResponse.



824
825
826
# File 'lib/google/apis/healthcare_v1/classes.rb', line 824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The resource names of all evaluated Consents mapped to their evaluation. Corresponds to the JSON property consentDetails



816
817
818
# File 'lib/google/apis/healthcare_v1/classes.rb', line 816

def consent_details
  @consent_details
end

#consentedBoolean Also known as: consented?

Whether the requested resource is consented for the given use. Corresponds to the JSON property consented

Returns:

  • (Boolean)


821
822
823
# File 'lib/google/apis/healthcare_v1/classes.rb', line 821

def consented
  @consented
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



829
830
831
832
# File 'lib/google/apis/healthcare_v1/classes.rb', line 829

def update!(**args)
  @consent_details = args[:consent_details] if args.key?(:consent_details)
  @consented = args[:consented] if args.key?(:consented)
end