Class: Google::Apis::HealthcareV1::ConsentArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Documentation of a user's consent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsentArtifact

Returns a new instance of ConsentArtifact.



1060
1061
1062
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Optional. Screenshots, PDFs, or other binary information documenting the user' s consent. Corresponds to the JSON property consentContentScreenshots



1018
1019
1020
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1018

def consent_content_screenshots
  @consent_content_screenshots
end

Optional. An string indicating the version of the consent information shown to the user. Corresponds to the JSON property consentContentVersion

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1024

def consent_content_version
  @consent_content_version
end

#guardian_signatureGoogle::Apis::HealthcareV1::Signature

User signature. Corresponds to the JSON property guardianSignature



1029
1030
1031
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1029

def guardian_signature
  @guardian_signature
end

#metadataHash<String,String>

Optional. Metadata associated with the Consent artifact. For example, the consent locale or user agent version. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


1035
1036
1037
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1035

def 
  @metadata
end

#nameString

Identifier. Resource name of the Consent artifact, of the form projects/ project_id/locations/location_id/datasets/dataset_id/consentStores/ consent_store_id/consentArtifacts/consent_artifact_id`. Cannot be changed after creation. Corresponds to the JSON propertyname`

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1043

def name
  @name
end

#user_idString

Required. User's UUID provided by the client. Corresponds to the JSON property userId

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1048

def user_id
  @user_id
end

#user_signatureGoogle::Apis::HealthcareV1::Signature

User signature. Corresponds to the JSON property userSignature



1053
1054
1055
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1053

def user_signature
  @user_signature
end

#witness_signatureGoogle::Apis::HealthcareV1::Signature

User signature. Corresponds to the JSON property witnessSignature



1058
1059
1060
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1058

def witness_signature
  @witness_signature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1065

def update!(**args)
  @consent_content_screenshots = args[:consent_content_screenshots] if args.key?(:consent_content_screenshots)
  @consent_content_version = args[:consent_content_version] if args.key?(:consent_content_version)
  @guardian_signature = args[:guardian_signature] if args.key?(:guardian_signature)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @user_id = args[:user_id] if args.key?(:user_id)
  @user_signature = args[:user_signature] if args.key?(:user_signature)
  @witness_signature = args[:witness_signature] if args.key?(:witness_signature)
end