Class: Google::Apis::HealthcareV1::ConsentErrors

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

The Consent resource name and error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsentErrors

Returns a new instance of ConsentErrors.



1166
1167
1168
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::HealthcareV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1154
1155
1156
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1154

def error
  @error
end

#nameString

The versioned name of the admin Consent resource, in the format projects/ project_id/locations/location/datasets/dataset_id/fhirStores/ fhir_store_id/fhir/Consent/resource_id/_history/version_id. For FHIR stores with `disable_resource_versioning=true`, the format is `projects/` project_id`/locations/`location`/datasets/`dataset_id`/fhirStores/` fhir_store_id`/fhir/Consent/`resource_id. Corresponds to the JSON property name

Returns:

  • (String)


1164
1165
1166
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1164

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1171
1172
1173
1174
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1171

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
end