Class: Google::Apis::HealthcareV1::DeidentifyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Configures de-id options specific to different types of content. Each submessage customizes the handling of an https://tools.ietf.org/html/rfc6838 media type or subtype. Configs are applied in a nested manner at runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeidentifyConfig

Returns a new instance of DeidentifyConfig.



1491
1492
1493
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dicomGoogle::Apis::HealthcareV1::DicomConfig

Specifies the parameters needed for de-identification of DICOM stores. Corresponds to the JSON property dicom



1463
1464
1465
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1463

def dicom
  @dicom
end

#fhirGoogle::Apis::HealthcareV1::FhirConfig

Specifies how to handle de-identification of a FHIR store. Corresponds to the JSON property fhir



1468
1469
1470
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1468

def fhir
  @fhir
end

#imageGoogle::Apis::HealthcareV1::ImageConfig

Specifies how to handle de-identification of image pixels. Corresponds to the JSON property image



1473
1474
1475
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1473

def image
  @image
end

#textGoogle::Apis::HealthcareV1::TextConfig

Optional. Configures de-identification of text wherever it is found in the source_dataset. Corresponds to the JSON property text



1479
1480
1481
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1479

def text
  @text
end

#use_regional_data_processingBoolean Also known as: use_regional_data_processing?

Optional. Ensures in-flight data remains in the region of origin during de- identification. The default value is false. Using this option results in a significant reduction of throughput, and is not compatible with LOCATION or ORGANIZATION_NAME infoTypes. LOCATION must be excluded within TextConfig, and must also be excluded within ImageConfig if image redaction is required. Corresponds to the JSON property useRegionalDataProcessing

Returns:

  • (Boolean)


1488
1489
1490
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1488

def use_regional_data_processing
  @use_regional_data_processing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1496
1497
1498
1499
1500
1501
1502
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1496

def update!(**args)
  @dicom = args[:dicom] if args.key?(:dicom)
  @fhir = args[:fhir] if args.key?(:fhir)
  @image = args[:image] if args.key?(:image)
  @text = args[:text] if args.key?(:text)
  @use_regional_data_processing = args[:use_regional_data_processing] if args.key?(:use_regional_data_processing)
end