Class: Google::Apis::HealthcareV1::DicomStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Represents a DICOM store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DicomStore

Returns a new instance of DicomStore.



1836
1837
1838
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

User-supplied key-value pairs used to organize DICOM stores. Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: \pLl\pLo 0,62 Label values are optional, must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be associated with a given store. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1806
1807
1808
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1806

def labels
  @labels
end

#nameString

Identifier. Resource name of the DICOM store, of the form projects/ project_id/locations/location_id/datasets/dataset_id/dicomStores/ dicom_store_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1813
1814
1815
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1813

def name
  @name
end

#notification_configGoogle::Apis::HealthcareV1::NotificationConfig

Specifies where to send notifications upon changes to a data store. Corresponds to the JSON property notificationConfig



1818
1819
1820
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1818

def notification_config
  @notification_config
end

#notification_configsArray<Google::Apis::HealthcareV1::DicomNotificationConfig>

Optional. Specifies where and whether to send notifications upon changes to a DICOM store. Corresponds to the JSON property notificationConfigs



1824
1825
1826
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1824

def notification_configs
  @notification_configs
end

#stream_configsArray<Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomStreamConfig>

Optional. A list of streaming configs used to configure the destination of streaming exports for every DICOM instance insertion in this DICOM store. After a new config is added to stream_configs, DICOM instance insertions are streamed to the new destination. When a config is removed from stream_configs , the server stops streaming to that destination. Each config must contain a unique destination. Corresponds to the JSON property streamConfigs



1834
1835
1836
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1834

def stream_configs
  @stream_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1841
1842
1843
1844
1845
1846
1847
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1841

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notification_config = args[:notification_config] if args.key?(:notification_config)
  @notification_configs = args[:notification_configs] if args.key?(:notification_configs)
  @stream_configs = args[:stream_configs] if args.key?(:stream_configs)
end