Class: Google::Apis::HealthcareV1::EntityMention

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

An entity mention in the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EntityMention

Returns a new instance of EntityMention.



2024
2025
2026
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certainty_assessmentGoogle::Apis::HealthcareV1::Feature

A feature of an entity mention. Corresponds to the JSON property certaintyAssessment



1978
1979
1980
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1978

def certainty_assessment
  @certainty_assessment
end

#confidenceFloat

The model's confidence in this entity mention annotation. A number between 0 and 1. Corresponds to the JSON property confidence

Returns:

  • (Float)


1984
1985
1986
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1984

def confidence
  @confidence
end

#linked_entitiesArray<Google::Apis::HealthcareV1::LinkedEntity>

linked_entities are candidate ontological concepts that this entity mention may refer to. They are sorted by decreasing confidence. Corresponds to the JSON property linkedEntities



1990
1991
1992
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1990

def linked_entities
  @linked_entities
end

#mention_idString

mention_id uniquely identifies each entity mention in a single response. Corresponds to the JSON property mentionId

Returns:

  • (String)


1995
1996
1997
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1995

def mention_id
  @mention_id
end

#subjectGoogle::Apis::HealthcareV1::Feature

A feature of an entity mention. Corresponds to the JSON property subject



2000
2001
2002
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2000

def subject
  @subject
end

#temporal_assessmentGoogle::Apis::HealthcareV1::Feature

A feature of an entity mention. Corresponds to the JSON property temporalAssessment



2005
2006
2007
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2005

def temporal_assessment
  @temporal_assessment
end

#textGoogle::Apis::HealthcareV1::TextSpan

A span of text in the provided document. Corresponds to the JSON property text



2010
2011
2012
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2010

def text
  @text
end

#typeString

The semantic type of the entity: UNKNOWN_ENTITY_TYPE, ALONE, ANATOMICAL_STRUCTURE, ASSISTED_LIVING, BF_RESULT, BM_RESULT, BM_UNIT, BM_VALUE, BODY_FUNCTION, BODY_MEASUREMENT, COMPLIANT, DOESNOT_FOLLOWUP, FAMILY, FOLLOWSUP, LABORATORY_DATA, LAB_RESULT, LAB_UNIT, LAB_VALUE, MEDICAL_DEVICE, MEDICINE, MED_DOSE, MED_DURATION, MED_FORM, MED_FREQUENCY, MED_ROUTE, MED_STATUS, MED_STRENGTH, MED_TOTALDOSE, MED_UNIT, NON_COMPLIANT, OTHER_LIVINGSTATUS, PROBLEM, PROCEDURE, PROCEDURE_RESULT, PROC_METHOD, REASON_FOR_NONCOMPLIANCE, SEVERITY, SUBSTANCE_ABUSE, UNCLEAR_FOLLOWUP. Corresponds to the JSON property type

Returns:

  • (String)


2022
2023
2024
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2022

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2029

def update!(**args)
  @certainty_assessment = args[:certainty_assessment] if args.key?(:certainty_assessment)
  @confidence = args[:confidence] if args.key?(:confidence)
  @linked_entities = args[:linked_entities] if args.key?(:linked_entities)
  @mention_id = args[:mention_id] if args.key?(:mention_id)
  @subject = args[:subject] if args.key?(:subject)
  @temporal_assessment = args[:temporal_assessment] if args.key?(:temporal_assessment)
  @text = args[:text] if args.key?(:text)
  @type = args[:type] if args.key?(:type)
end