Class: Google::Apis::HealthcareV1::ExportDicomDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ExportDicomDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Exports data from the specified DICOM store. If a given resource, such as a DICOM object with the same SOPInstance UID, already exists in the output, it is overwritten with the version in the source dataset. Exported DICOM data persists when the DICOM store from which it was exported is deleted.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomBigQueryDestination
The BigQuery table where the server writes the output.
-
#gcs_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsDestination
The Cloud Storage location where the server writes the output and the export configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportDicomDataRequest
constructor
A new instance of ExportDicomDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportDicomDataRequest
Returns a new instance of ExportDicomDataRequest.
2317 2318 2319 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomBigQueryDestination
The BigQuery table where the server writes the output.
Corresponds to the JSON property bigqueryDestination
2309 2310 2311 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2309 def bigquery_destination @bigquery_destination end |
#gcs_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsDestination
The Cloud Storage location where the server writes the output and the export
configuration.
Corresponds to the JSON property gcsDestination
2315 2316 2317 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2315 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2322 2323 2324 2325 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2322 def update!(**args) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |