Class: Google::Apis::HealthcareV1::ExportResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Request to export resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportResourcesRequest

Returns a new instance of ExportResourcesRequest.



2418
2419
2420
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#_sinceString

If provided, only resources updated after this time are exported. The time uses the format YYYY-MM-DDThh:mm:ss.sss+zz:zz. For example, 2015-02-07T13:28: 17.239+02:00 or 2017-01-01T00:00:00Z. The time must be specified to the second and include a time zone. Corresponds to the JSON property _since

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2400

def _since
  @_since
end

#_typeString

String of comma-delimited FHIR resource types. If provided, only resources of the specified resource type(s) are exported. Corresponds to the JSON property _type

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2406

def _type
  @_type
end

#bigquery_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirBigQueryDestination

The configuration for exporting to BigQuery. Corresponds to the JSON property bigqueryDestination



2411
2412
2413
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2411

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirGcsDestination

The configuration for exporting to Cloud Storage. Corresponds to the JSON property gcsDestination



2416
2417
2418
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2416

def gcs_destination
  @gcs_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2423
2424
2425
2426
2427
2428
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2423

def update!(**args)
  @_since = args[:_since] if args.key?(:_since)
  @_type = args[:_type] if args.key?(:_type)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
end