Class: Google::Apis::HealthcareV1::FhirStoreMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Count of resources and total storage size by type for a given FHIR store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FhirStoreMetric

Returns a new instance of FhirStoreMetric.



2872
2873
2874
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The total count of FHIR resources in the store of this resource type. Corresponds to the JSON property count

Returns:

  • (Fixnum)


2853
2854
2855
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2853

def count
  @count
end

#resource_typeString

The FHIR resource type this metric applies to. Corresponds to the JSON property resourceType

Returns:

  • (String)


2858
2859
2860
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2858

def resource_type
  @resource_type
end

#structured_storage_size_bytesFixnum

The total amount of structured storage used by FHIR resources of this resource type in the store. Corresponds to the JSON property structuredStorageSizeBytes

Returns:

  • (Fixnum)


2864
2865
2866
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2864

def structured_storage_size_bytes
  @structured_storage_size_bytes
end

#versioned_storage_size_bytesFixnum

The total amount of versioned storage used by versioned FHIR resources of this resource type in the store. Corresponds to the JSON property versionedStorageSizeBytes

Returns:

  • (Fixnum)


2870
2871
2872
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2870

def versioned_storage_size_bytes
  @versioned_storage_size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2877
2878
2879
2880
2881
2882
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2877

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes)
  @versioned_storage_size_bytes = args[:versioned_storage_size_bytes] if args.key?(:versioned_storage_size_bytes)
end