Class: Google::Apis::HealthcareV1::GoogleCloudHealthcareV1ConsentPolicy
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::GoogleCloudHealthcareV1ConsentPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Represents a user's consent in terms of the resources that can be accessed and under what conditions.
Instance Attribute Summary collapse
-
#authorization_rule ⇒ Google::Apis::HealthcareV1::Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
-
#resource_attributes ⇒ Array<Google::Apis::HealthcareV1::Attribute>
The resources that this policy applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudHealthcareV1ConsentPolicy
constructor
A new instance of GoogleCloudHealthcareV1ConsentPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudHealthcareV1ConsentPolicy
Returns a new instance of GoogleCloudHealthcareV1ConsentPolicy.
3109 3110 3111 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_rule ⇒ Google::Apis::HealthcareV1::Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
CEL is a C-like expression language. The syntax and semantics of CEL are
documented at https://github.com/google/cel-spec. Example (Comparison): title:
"Summary size limit" description: "Determines if a summary is less than 100
chars" expression: "document.summary.size() < 100" Example (Equality): title: "
Requestor is owner" description: "Determines if requestor is the document
owner" expression: "document.owner == request.auth.claims.email" Example (
Logic): title: "Public documents" description: "Determine whether the document
should be publicly visible" expression: "document.type != 'private' &&
document.type != 'internal'" Example (Data Manipulation): title: "Notification
string" description: "Create a notification string with a timestamp."
expression: "'New message received at ' + string(document.create_time)" The
exact variables and functions that may be referenced within an expression are
determined by the service that evaluates it. See the service documentation for
additional information.
Corresponds to the JSON property authorizationRule
3100 3101 3102 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3100 def @authorization_rule end |
#resource_attributes ⇒ Array<Google::Apis::HealthcareV1::Attribute>
The resources that this policy applies to. A resource is a match if it matches
all the attributes listed here. If empty, this policy applies to all User data
mappings for the given user.
Corresponds to the JSON property resourceAttributes
3107 3108 3109 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3107 def resource_attributes @resource_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3114 3115 3116 3117 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3114 def update!(**args) @authorization_rule = args[:authorization_rule] if args.key?(:authorization_rule) @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes) end |