Class: Google::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirGcsSource
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirGcsSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Specifies the configuration for importing data from Cloud Storage.
Instance Attribute Summary collapse
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudHealthcareV1FhirGcsSource
constructor
A new instance of GoogleCloudHealthcareV1FhirGcsSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudHealthcareV1FhirGcsSource
Returns a new instance of GoogleCloudHealthcareV1FhirGcsSource.
3425 3426 3427 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#uri ⇒ String
Required. Points to a Cloud Storage URI containing file(s) to import. The URI
must be in the following format: gs://bucket_id/object_id`. The URI can
include wildcards inobject_idand thus identify multiple files. Supported
wildcards: *to match 0 or more non-separator characters *to match 0
or more characters (including separators). Must be used at the end of a path
and with no other wildcards in the path. Can also be used with a file
extension (such as .ndjson), which imports all files with the extension in the
specified directory and its sub-directories. For example,gs://my-bucket/my-
directory/*.ndjsonimports all files with.ndjsonextensions inmy-
directory/and its sub-directories. *?to match 1 character Files matching
the wildcard are expected to contain content only, no metadata.
Corresponds to the JSON propertyuri`
3423 3424 3425 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3423 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3430 3431 3432 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3430 def update!(**args) @uri = args[:uri] if args.key?(:uri) end |