Class: Google::Apis::HealthcareV1::ImportDicomDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Imports data into the specified DICOM store. Returns an error if any of the files to import are not DICOM files. This API accepts duplicate DICOM instances by ignoring the newly-pushed instance. It does not overwrite.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportDicomDataRequest

Returns a new instance of ImportDicomDataRequest.



3829
3830
3831
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_settingsGoogle::Apis::HealthcareV1::BlobStorageSettings

Settings for data stored in Blob storage. Corresponds to the JSON property blobStorageSettings



3822
3823
3824
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3822

def blob_storage_settings
  @blob_storage_settings
end

#gcs_sourceGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsSource

Specifies the configuration for importing data from Cloud Storage. Corresponds to the JSON property gcsSource



3827
3828
3829
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3827

def gcs_source
  @gcs_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3834
3835
3836
3837
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3834

def update!(**args)
  @blob_storage_settings = args[:blob_storage_settings] if args.key?(:blob_storage_settings)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
end