Class: Google::Apis::HealthcareV1::ListConsentArtifactsResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ListConsentArtifactsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Instance Attribute Summary collapse
-
#consent_artifacts ⇒ Array<Google::Apis::HealthcareV1::ConsentArtifact>
The returned Consent artifacts.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConsentArtifactsResponse
constructor
A new instance of ListConsentArtifactsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConsentArtifactsResponse
Returns a new instance of ListConsentArtifactsResponse.
4129 4130 4131 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_artifacts ⇒ Array<Google::Apis::HealthcareV1::ConsentArtifact>
The returned Consent artifacts. The maximum number of artifacts returned is
determined by the value of page_size in the ListConsentArtifactsRequest.
Corresponds to the JSON property consentArtifacts
4121 4122 4123 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4121 def @consent_artifacts end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
4127 4128 4129 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4127 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4134 4135 4136 4137 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4134 def update!(**args) @consent_artifacts = args[:consent_artifacts] if args.key?(:consent_artifacts) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |