Class: Google::Apis::HealthcareV1::ListHl7V2StoresResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Lists the HL7v2 stores in the given dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListHl7V2StoresResponse

Returns a new instance of ListHl7V2StoresResponse.



4311
4312
4313
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hl7_v2_storesArray<Google::Apis::HealthcareV1::Hl7V2Store>

The returned HL7v2 stores. Won't be more HL7v2 stores than the value of page_size in the request. Corresponds to the JSON property hl7V2Stores



4303
4304
4305
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4303

def hl7_v2_stores
  @hl7_v2_stores
end

#next_page_tokenString

Token to retrieve the next page of results or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4309
4310
4311
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4309

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4316
4317
4318
4319
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4316

def update!(**args)
  @hl7_v2_stores = args[:hl7_v2_stores] if args.key?(:hl7_v2_stores)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end