Class: Google::Apis::HealthcareV1::Location
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::Location
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
4475 4476 4477 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4475 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
4450 4451 4452 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4450 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
4456 4457 4458 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4456 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
4461 4462 4463 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4461 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
4467 4468 4469 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4467 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
4473 4474 4475 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4473 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4480 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |