Class: Google::Apis::HealthcareV1::Message

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

A complete HL7v2 message. See Introduction to HL7 Standards for details on the standard.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



4555
4556
4557
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The datetime when the message was created. Set by the server. Corresponds to the JSON property createTime

Returns:

  • (String)


4497
4498
4499
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4497

def create_time
  @create_time
end

#dataString

Required. Raw message bytes. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4503
4504
4505
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4503

def data
  @data
end

#labelsHash<String,String>

User-supplied key-value pairs used to organize HL7v2 stores. Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: \pLl\pLo 0,62 Label values are optional, must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be associated with a given store. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4514
4515
4516
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4514

def labels
  @labels
end

#message_typeString

Output only. The message type for this message. MSH-9.1. Corresponds to the JSON property messageType

Returns:

  • (String)


4519
4520
4521
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4519

def message_type
  @message_type
end

#nameString

Output only. Resource name of the Message, of the form projects/project_id/ locations/location_id/datasets/dataset_id/hl7V2Stores/hl7_v2_store_id/ messages/message_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4526
4527
4528
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4526

def name
  @name
end

#parsed_dataGoogle::Apis::HealthcareV1::ParsedData

The content of a HL7v2 message in a structured format. Corresponds to the JSON property parsedData



4531
4532
4533
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4531

def parsed_data
  @parsed_data
end

#patient_idsArray<Google::Apis::HealthcareV1::PatientId>

Output only. All patient IDs listed in the PID-2, PID-3, and PID-4 segments of this message. Corresponds to the JSON property patientIds



4537
4538
4539
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4537

def patient_ids
  @patient_ids
end

#schematized_dataGoogle::Apis::HealthcareV1::SchematizedData

The content of an HL7v2 message in a structured format as specified by a schema. Corresponds to the JSON property schematizedData



4543
4544
4545
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4543

def schematized_data
  @schematized_data
end

#send_facilityString

Output only. The hospital that this message came from. MSH-4. Corresponds to the JSON property sendFacility

Returns:

  • (String)


4548
4549
4550
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4548

def send_facility
  @send_facility
end

#send_timeString

Output only. The datetime the sending application sent this message. MSH-7. Corresponds to the JSON property sendTime

Returns:

  • (String)


4553
4554
4555
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4553

def send_time
  @send_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4560
4561
4562
4563
4564
4565
4566
4567
4568
4569
4570
4571
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4560

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data = args[:data] if args.key?(:data)
  @labels = args[:labels] if args.key?(:labels)
  @message_type = args[:message_type] if args.key?(:message_type)
  @name = args[:name] if args.key?(:name)
  @parsed_data = args[:parsed_data] if args.key?(:parsed_data)
  @patient_ids = args[:patient_ids] if args.key?(:patient_ids)
  @schematized_data = args[:schematized_data] if args.key?(:schematized_data)
  @send_facility = args[:send_facility] if args.key?(:send_facility)
  @send_time = args[:send_time] if args.key?(:send_time)
end