Class: Google::Apis::HealthcareV1::Result

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

The consent evaluation result for a single data_id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Result

Returns a new instance of Result.



5152
5153
5154
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The resource names of all evaluated Consents mapped to their evaluation. Corresponds to the JSON property consentDetails



5139
5140
5141
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5139

def consent_details
  @consent_details
end

#consentedBoolean Also known as: consented?

Whether the resource is consented for the given use. Corresponds to the JSON property consented

Returns:

  • (Boolean)


5144
5145
5146
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5144

def consented
  @consented
end

#data_idString

The unique identifier of the evaluated resource. Corresponds to the JSON property dataId

Returns:

  • (String)


5150
5151
5152
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5150

def data_id
  @data_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5157
5158
5159
5160
5161
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5157

def update!(**args)
  @consent_details = args[:consent_details] if args.key?(:consent_details)
  @consented = args[:consented] if args.key?(:consented)
  @data_id = args[:data_id] if args.key?(:data_id)
end