Class: Google::Apis::HealthcareV1::RollbackHl7V2MessagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Point in time recovery rollback request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackHl7V2MessagesRequest

Returns a new instance of RollbackHl7V2MessagesRequest.



5365
5366
5367
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type. Corresponds to the JSON property changeType

Returns:

  • (String)


5329
5330
5331
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5329

def change_type
  @change_type
end

#exclude_rollbacksBoolean Also known as: exclude_rollbacks?

Optional. Specifies whether to exclude earlier rollbacks. Corresponds to the JSON property excludeRollbacks

Returns:

  • (Boolean)


5334
5335
5336
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5334

def exclude_rollbacks
  @exclude_rollbacks
end

#filtering_fieldsGoogle::Apis::HealthcareV1::RollbackHl7MessagesFilteringFields

Filtering fields for an HL7v2 rollback. Currently only supports a list of operation ids to roll back. Corresponds to the JSON property filteringFields



5341
5342
5343
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5341

def filtering_fields
  @filtering_fields
end

#forceBoolean Also known as: force?

Optional. When enabled, changes will be reverted without explicit confirmation. Corresponds to the JSON property force

Returns:

  • (Boolean)


5346
5347
5348
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5346

def force
  @force
end

#input_gcs_objectString

Optional. Cloud storage object containing list of resourceId lines, identifying resources to be reverted Corresponds to the JSON property inputGcsObject

Returns:

  • (String)


5353
5354
5355
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5353

def input_gcs_object
  @input_gcs_object
end

#result_gcs_bucketString

Required. Bucket to deposit result Corresponds to the JSON property resultGcsBucket

Returns:

  • (String)


5358
5359
5360
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5358

def result_gcs_bucket
  @result_gcs_bucket
end

#rollback_timeString

Required. Times point to rollback to. Corresponds to the JSON property rollbackTime

Returns:

  • (String)


5363
5364
5365
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5363

def rollback_time
  @rollback_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5370
5371
5372
5373
5374
5375
5376
5377
5378
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5370

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks)
  @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields)
  @force = args[:force] if args.key?(:force)
  @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object)
  @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket)
  @rollback_time = args[:rollback_time] if args.key?(:rollback_time)
end