Class: Google::Apis::HealthcareV1::SchemaConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::SchemaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Configuration for the FHIR BigQuery schema. Determines how the server generates the schema.
Instance Attribute Summary collapse
-
#last_updated_partition_config ⇒ Google::Apis::HealthcareV1::TimePartitioning
Configuration for FHIR BigQuery time-partitioned tables.
-
#recursive_structure_depth ⇒ Fixnum
The depth for all recursive structures in the output analytics schema.
-
#schema_type ⇒ String
Specifies the output schema type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaConfig
constructor
A new instance of SchemaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaConfig
Returns a new instance of SchemaConfig.
5432 5433 5434 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_updated_partition_config ⇒ Google::Apis::HealthcareV1::TimePartitioning
Configuration for FHIR BigQuery time-partitioned tables.
Corresponds to the JSON property lastUpdatedPartitionConfig
5416 5417 5418 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5416 def last_updated_partition_config @last_updated_partition_config end |
#recursive_structure_depth ⇒ Fixnum
The depth for all recursive structures in the output analytics schema. For
example, concept in the CodeSystem resource is a recursive structure; when
the depth is 2, the CodeSystem table will have a column called concept.
concept but not concept.concept.concept. If not specified or set to 0, the
server will use the default value 2. The maximum depth allowed is 5.
Corresponds to the JSON property recursiveStructureDepth
5425 5426 5427 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5425 def recursive_structure_depth @recursive_structure_depth end |
#schema_type ⇒ String
Specifies the output schema type. Schema type is required.
Corresponds to the JSON property schemaType
5430 5431 5432 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5430 def schema_type @schema_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5437 5438 5439 5440 5441 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5437 def update!(**args) @last_updated_partition_config = args[:last_updated_partition_config] if args.key?(:last_updated_partition_config) @recursive_structure_depth = args[:recursive_structure_depth] if args.key?(:recursive_structure_depth) @schema_type = args[:schema_type] if args.key?(:schema_type) end |