Class: Google::Apis::HealthcareV1::SchemaSegment
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::SchemaSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
An HL7v2 Segment.
Instance Attribute Summary collapse
-
#max_occurs ⇒ Fixnum
The maximum number of times this segment can be present in this group.
-
#min_occurs ⇒ Fixnum
The minimum number of times this segment can be present in this group.
-
#type ⇒ String
The Segment type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaSegment
constructor
A new instance of SchemaSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaSegment
Returns a new instance of SchemaSegment.
5605 5606 5607 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_occurs ⇒ Fixnum
The maximum number of times this segment can be present in this group. 0 or -1
means unbounded.
Corresponds to the JSON property maxOccurs
5593 5594 5595 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5593 def max_occurs @max_occurs end |
#min_occurs ⇒ Fixnum
The minimum number of times this segment can be present in this group.
Corresponds to the JSON property minOccurs
5598 5599 5600 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5598 def min_occurs @min_occurs end |
#type ⇒ String
The Segment type. For example, "PID".
Corresponds to the JSON property type
5603 5604 5605 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5603 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5610 5611 5612 5613 5614 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5610 def update!(**args) @max_occurs = args[:max_occurs] if args.key?(:max_occurs) @min_occurs = args[:min_occurs] if args.key?(:min_occurs) @type = args[:type] if args.key?(:type) end |