Class: Google::Apis::HealthcareV1::StreamConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Contains configuration for streaming FHIR export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamConfig

Returns a new instance of StreamConfig.



5949
5950
5951
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirBigQueryDestination

The configuration for exporting to BigQuery. Corresponds to the JSON property bigqueryDestination



5934
5935
5936
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5934

def bigquery_destination
  @bigquery_destination
end

#deidentified_store_destinationGoogle::Apis::HealthcareV1::DeidentifiedStoreDestination

Contains configuration for streaming de-identified FHIR export. Corresponds to the JSON property deidentifiedStoreDestination



5939
5940
5941
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5939

def deidentified_store_destination
  @deidentified_store_destination
end

#resource_typesArray<String>

Optional. Supply a FHIR resource type (such as "Patient" or "Observation"). See https://www.hl7.org/fhir/valueset-resource-types.html for a list of all FHIR resource types. The server treats an empty list as an intent to stream all the supported resource types in this FHIR store. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


5947
5948
5949
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5947

def resource_types
  @resource_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5954
5955
5956
5957
5958
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5954

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @deidentified_store_destination = args[:deidentified_store_destination] if args.key?(:deidentified_store_destination)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
end