Class: Google::Apis::HealthcareV1::StudyMetrics
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::StudyMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
StudyMetrics contains metrics describing a DICOM study.
Instance Attribute Summary collapse
-
#blob_storage_size_bytes ⇒ Fixnum
Total blob storage bytes for all instances in the study.
-
#instance_count ⇒ Fixnum
Number of instances in the study.
-
#series_count ⇒ Fixnum
Number of series in the study.
-
#structured_storage_size_bytes ⇒ Fixnum
Total structured storage bytes for all instances in the study.
-
#study ⇒ String
The study resource path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StudyMetrics
constructor
A new instance of StudyMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StudyMetrics
Returns a new instance of StudyMetrics.
5866 5867 5868 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_size_bytes ⇒ Fixnum
Total blob storage bytes for all instances in the study.
Corresponds to the JSON property blobStorageSizeBytes
5842 5843 5844 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5842 def blob_storage_size_bytes @blob_storage_size_bytes end |
#instance_count ⇒ Fixnum
Number of instances in the study.
Corresponds to the JSON property instanceCount
5847 5848 5849 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5847 def instance_count @instance_count end |
#series_count ⇒ Fixnum
Number of series in the study.
Corresponds to the JSON property seriesCount
5852 5853 5854 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5852 def series_count @series_count end |
#structured_storage_size_bytes ⇒ Fixnum
Total structured storage bytes for all instances in the study.
Corresponds to the JSON property structuredStorageSizeBytes
5857 5858 5859 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5857 def structured_storage_size_bytes @structured_storage_size_bytes end |
#study ⇒ String
The study resource path. For example, projects/project_id/locations/
location_id/datasets/dataset_id/dicomStores/dicom_store_id/dicomWeb/
studies/study_uid`.
Corresponds to the JSON propertystudy`
5864 5865 5866 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5864 def study @study end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5871 5872 5873 5874 5875 5876 5877 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5871 def update!(**args) @blob_storage_size_bytes = args[:blob_storage_size_bytes] if args.key?(:blob_storage_size_bytes) @instance_count = args[:instance_count] if args.key?(:instance_count) @series_count = args[:series_count] if args.key?(:series_count) @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes) @study = args[:study] if args.key?(:study) end |