Class: Google::Apis::HealthcareV1::ApplyAdminConsentsErrorDetail
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ApplyAdminConsentsErrorDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Contains the error details of the unsupported admin Consent resources for when the ApplyAdminConsents method fails to apply one or more Consent resources.
Instance Attribute Summary collapse
-
#consent_errors ⇒ Array<Google::Apis::HealthcareV1::ConsentErrors>
The list of Consent resources that are unsupported or cannot be applied and the error associated with each of them.
-
#existing_operation_id ⇒ Fixnum
The currently in progress non-validate-only ApplyAdminConsents operation ID if exist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApplyAdminConsentsErrorDetail
constructor
A new instance of ApplyAdminConsentsErrorDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApplyAdminConsentsErrorDetail
Returns a new instance of ApplyAdminConsentsErrorDetail.
202 203 204 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_errors ⇒ Array<Google::Apis::HealthcareV1::ConsentErrors>
The list of Consent resources that are unsupported or cannot be applied and
the error associated with each of them.
Corresponds to the JSON property consentErrors
194 195 196 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 194 def @consent_errors end |
#existing_operation_id ⇒ Fixnum
The currently in progress non-validate-only ApplyAdminConsents operation ID if
exist.
Corresponds to the JSON property existingOperationId
200 201 202 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 200 def existing_operation_id @existing_operation_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
207 208 209 210 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 207 def update!(**args) @consent_errors = args[:consent_errors] if args.key?(:consent_errors) @existing_operation_id = args[:existing_operation_id] if args.key?(:existing_operation_id) end |