Class: Google::Apis::HealthcareV1::CheckDataAccessRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Checks if a particular data_id of a User data mapping in the given consent store is consented for a given use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CheckDataAccessRequest

Returns a new instance of CheckDataAccessRequest.



795
796
797
# File 'lib/google/apis/healthcare_v1/classes.rb', line 795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of resource names of Consent resources. Corresponds to the JSON property consentList



776
777
778
# File 'lib/google/apis/healthcare_v1/classes.rb', line 776

def consent_list
  @consent_list
end

#data_idString

Required. The unique identifier of the resource to check access for. This identifier must correspond to a User data mapping in the given consent store. Corresponds to the JSON property dataId

Returns:

  • (String)


782
783
784
# File 'lib/google/apis/healthcare_v1/classes.rb', line 782

def data_id
  @data_id
end

#request_attributesHash<String,String>

The values of request attributes associated with this access request. Corresponds to the JSON property requestAttributes

Returns:

  • (Hash<String,String>)


787
788
789
# File 'lib/google/apis/healthcare_v1/classes.rb', line 787

def request_attributes
  @request_attributes
end

#response_viewString

Optional. The view for CheckDataAccessResponse. If unspecified, defaults to BASIC and returns consented as TRUE or FALSE. Corresponds to the JSON property responseView

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/healthcare_v1/classes.rb', line 793

def response_view
  @response_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



800
801
802
803
804
805
# File 'lib/google/apis/healthcare_v1/classes.rb', line 800

def update!(**args)
  @consent_list = args[:consent_list] if args.key?(:consent_list)
  @data_id = args[:data_id] if args.key?(:data_id)
  @request_attributes = args[:request_attributes] if args.key?(:request_attributes)
  @response_view = args[:response_view] if args.key?(:response_view)
end