Class: Google::Apis::HealthcareV1::ConsentAccessorScope
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ConsentAccessorScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
The accessor scope that describes who can access, for what purpose, in which environment.
Instance Attribute Summary collapse
-
#actor ⇒ String
An individual, group, or access role that identifies the accessor or a characteristic of the accessor.
-
#environment ⇒ String
An abstract identifier that describes the environment or conditions under which the accessor is acting.
-
#purpose ⇒ String
The intent of data use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentAccessorScope
constructor
A new instance of ConsentAccessorScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentAccessorScope
Returns a new instance of ConsentAccessorScope.
998 999 1000 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor ⇒ String
An individual, group, or access role that identifies the accessor or a
characteristic of the accessor. This can be a resource ID (such as
resourceType`/`id) or an external URI. This value must be present.
Corresponds to the JSON property actor
984 985 986 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 984 def actor @actor end |
#environment ⇒ String
An abstract identifier that describes the environment or conditions under
which the accessor is acting. If it's not specified, it applies to all
environments.
Corresponds to the JSON property environment
991 992 993 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 991 def environment @environment end |
#purpose ⇒ String
The intent of data use. If it's not specified, it applies to all purposes.
Corresponds to the JSON property purpose
996 997 998 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 996 def purpose @purpose end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1003 1004 1005 1006 1007 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1003 def update!(**args) @actor = args[:actor] if args.key?(:actor) @environment = args[:environment] if args.key?(:environment) @purpose = args[:purpose] if args.key?(:purpose) end |