Class: Google::Apis::HealthcareV1::ConsentAccessorScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

The accessor scope that describes who can access, for what purpose, in which environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsentAccessorScope

Returns a new instance of ConsentAccessorScope.



947
948
949
# File 'lib/google/apis/healthcare_v1/classes.rb', line 947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actorString

An individual, group, or access role that identifies the accessor or a characteristic of the accessor. This can be a resource ID (such as resourceType`/`id) or an external URI. This value must be present. Corresponds to the JSON property actor

Returns:

  • (String)


933
934
935
# File 'lib/google/apis/healthcare_v1/classes.rb', line 933

def actor
  @actor
end

#environmentString

An abstract identifier that describes the environment or conditions under which the accessor is acting. If it's not specified, it applies to all environments. Corresponds to the JSON property environment

Returns:

  • (String)


940
941
942
# File 'lib/google/apis/healthcare_v1/classes.rb', line 940

def environment
  @environment
end

#purposeString

The intent of data use. If it's not specified, it applies to all purposes. Corresponds to the JSON property purpose

Returns:

  • (String)


945
946
947
# File 'lib/google/apis/healthcare_v1/classes.rb', line 945

def purpose
  @purpose
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



952
953
954
955
956
# File 'lib/google/apis/healthcare_v1/classes.rb', line 952

def update!(**args)
  @actor = args[:actor] if args.key?(:actor)
  @environment = args[:environment] if args.key?(:environment)
  @purpose = args[:purpose] if args.key?(:purpose)
end