Class: Google::Apis::HealthcareV1::ConsentConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ConsentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Configures whether to enforce consent for the FHIR store and which consent enforcement version is being used.
Instance Attribute Summary collapse
-
#access_determination_log_config ⇒ Google::Apis::HealthcareV1::AccessDeterminationLogConfig
Configures consent audit log config for FHIR create, read, update, and delete ( CRUD) operations.
-
#access_enforced ⇒ Boolean
(also: #access_enforced?)
Optional.
-
#consent_header_handling ⇒ Google::Apis::HealthcareV1::ConsentHeaderHandling
How the server handles the consent header.
-
#enforced_admin_consents ⇒ Array<String>
Output only.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentConfig
constructor
A new instance of ConsentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentConfig
Returns a new instance of ConsentConfig.
1122 1123 1124 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_determination_log_config ⇒ Google::Apis::HealthcareV1::AccessDeterminationLogConfig
Configures consent audit log config for FHIR create, read, update, and delete (
CRUD) operations. Cloud audit log for healthcare API must be enabled. The consent-related logs are included as part of protoPayload.
metadata.
Corresponds to the JSON property accessDeterminationLogConfig
1089 1090 1091 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1089 def access_determination_log_config @access_determination_log_config end |
#access_enforced ⇒ Boolean Also known as: access_enforced?
Optional. The default value is false. If set to true, when accessing FHIR
resources, the consent headers will be verified against consents given by
patients. See the ConsentEnforcementVersion for the supported consent headers.
Corresponds to the JSON property accessEnforced
1096 1097 1098 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1096 def access_enforced @access_enforced end |
#consent_header_handling ⇒ Google::Apis::HealthcareV1::ConsentHeaderHandling
How the server handles the consent header.
Corresponds to the JSON property consentHeaderHandling
1102 1103 1104 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1102 def @consent_header_handling end |
#enforced_admin_consents ⇒ Array<String>
Output only. The versioned names of the enforced admin Consent resource(s), in
the format projects/project_id/locations/location/datasets/dataset_id/
fhirStores/fhir_store_id/fhir/Consent/resource_id/_history/version_id.
For FHIR stores with `disable_resource_versioning=true`, the format is `
projects/`project_id`/locations/`location`/datasets/`dataset_id`/fhirStores/`
fhir_store_id`/fhir/Consent/`resource_id. This field can only be updated
using ApplyAdminConsents.
Corresponds to the JSON property enforcedAdminConsents
1113 1114 1115 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1113 def @enforced_admin_consents end |
#version ⇒ String
Required. Specifies which consent enforcement version is being used for this
FHIR store. This field can only be set once by either CreateFhirStore or
UpdateFhirStore. After that, you must call ApplyConsents to change the version.
Corresponds to the JSON property version
1120 1121 1122 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1120 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1127 1128 1129 1130 1131 1132 1133 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1127 def update!(**args) @access_determination_log_config = args[:access_determination_log_config] if args.key?(:access_determination_log_config) @access_enforced = args[:access_enforced] if args.key?(:access_enforced) @consent_header_handling = args[:consent_header_handling] if args.key?(:consent_header_handling) @enforced_admin_consents = args[:enforced_admin_consents] if args.key?(:enforced_admin_consents) @version = args[:version] if args.key?(:version) end |