Class: Google::Apis::HealthcareV1::ConsentStore
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ConsentStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Represents a consent store.
Instance Attribute Summary collapse
-
#default_consent_ttl ⇒ String
Optional.
-
#enable_consent_create_on_update ⇒ Boolean
(also: #enable_consent_create_on_update?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentStore
constructor
A new instance of ConsentStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentStore
Returns a new instance of ConsentStore.
1274 1275 1276 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_consent_ttl ⇒ String
Optional. Default time to live for Consents created in this store. Must be at
least 24 hours. Updating this field will not affect the expiration time of
existing consents.
Corresponds to the JSON property defaultConsentTtl
1246 1247 1248 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1246 def @default_consent_ttl end |
#enable_consent_create_on_update ⇒ Boolean Also known as: enable_consent_create_on_update?
Optional. If true, UpdateConsent creates the Consent if it does not already
exist. If unspecified, defaults to false.
Corresponds to the JSON property enableConsentCreateOnUpdate
1252 1253 1254 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1252 def @enable_consent_create_on_update end |
#labels ⇒ Hash<String,String>
Optional. User-supplied key-value pairs used to organize consent stores. Label
keys must be between 1 and 63 characters long, have a UTF-8 encoding of
maximum 128 bytes, and must conform to the following PCRE regular expression: \
pLl\pLo0,62. Label values must be between 1 and 63 characters long, have
a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE
regular expression: [\pLl\pLo\pN_-]0,63. No more than 64 labels can be
associated with a given store. For more information: https://cloud.google.com/
healthcare/docs/how-tos/labeling-resources
Corresponds to the JSON property labels
1265 1266 1267 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1265 def labels @labels end |
#name ⇒ String
Identifier. Resource name of the consent store, of the form projects/
project_id/locations/location_id/datasets/dataset_id/consentStores/
consent_store_id`. Cannot be changed after creation.
Corresponds to the JSON propertyname`
1272 1273 1274 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1272 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1279 1280 1281 1282 1283 1284 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1279 def update!(**args) @default_consent_ttl = args[:default_consent_ttl] if args.key?(:default_consent_ttl) @enable_consent_create_on_update = args[:enable_consent_create_on_update] if args.key?(:enable_consent_create_on_update) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) end |