Class: Google::Apis::HealthcareV1::Dataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

A message representing a health dataset. A health dataset represents a collection of healthcare data pertaining to one or more patients. This may include multiple modalities of healthcare data, such as electronic medical records or medical imaging data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dataset

Returns a new instance of Dataset.



1375
1376
1377
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_specGoogle::Apis::HealthcareV1::EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a resource. Corresponds to the JSON property encryptionSpec



1347
1348
1349
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1347

def encryption_spec
  @encryption_spec
end

#nameString

Identifier. Resource name of the dataset, of the form projects/project_id/ locations/location_id/datasets/dataset_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1353
1354
1355
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1353

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Whether the dataset satisfies zone isolation. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1358
1359
1360
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1358

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Whether the dataset satisfies zone separation. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1364
1365
1366
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1364

def satisfies_pzs
  @satisfies_pzs
end

#time_zoneString

Optional. The default timezone used by this dataset. Must be a either a valid IANA time zone name such as "America/New_York" or empty, which defaults to UTC. This is used for parsing times in resources, such as HL7 messages, where no explicit timezone is specified. Corresponds to the JSON property timeZone

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1373

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
1384
1385
1386
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1380

def update!(**args)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end