Class: Google::Apis::HealthcareV1::Dataset
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
A message representing a health dataset. A health dataset represents a collection of healthcare data pertaining to one or more patients. This may include multiple modalities of healthcare data, such as electronic medical records or medical imaging data.
Instance Attribute Summary collapse
-
#encryption_spec ⇒ Google::Apis::HealthcareV1::EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a resource.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#time_zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dataset
constructor
A new instance of Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dataset
Returns a new instance of Dataset.
1324 1325 1326 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_spec ⇒ Google::Apis::HealthcareV1::EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a
resource.
Corresponds to the JSON property encryptionSpec
1296 1297 1298 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1296 def encryption_spec @encryption_spec end |
#name ⇒ String
Identifier. Resource name of the dataset, of the form projects/project_id/
locations/location_id/datasets/dataset_id`.
Corresponds to the JSON propertyname`
1302 1303 1304 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1302 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Whether the dataset satisfies zone isolation.
Corresponds to the JSON property satisfiesPzi
1307 1308 1309 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1307 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Whether the dataset satisfies zone separation.
Corresponds to the JSON property satisfiesPzs
1313 1314 1315 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1313 def satisfies_pzs @satisfies_pzs end |
#time_zone ⇒ String
Optional. The default timezone used by this dataset. Must be a either a valid
IANA time zone name such as "America/New_York" or empty, which defaults to UTC.
This is used for parsing times in resources, such as HL7 messages, where no
explicit timezone is specified.
Corresponds to the JSON property timeZone
1322 1323 1324 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1322 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1329 1330 1331 1332 1333 1334 1335 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1329 def update!(**args) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @time_zone = args[:time_zone] if args.key?(:time_zone) end |