Class: Google::Apis::HealthcareV1::DeidentifiedStoreDestination
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::DeidentifiedStoreDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Contains configuration for streaming de-identified FHIR export.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::HealthcareV1::DeidentifyConfig
Configures de-id options specific to different types of content.
-
#store ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeidentifiedStoreDestination
constructor
A new instance of DeidentifiedStoreDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeidentifiedStoreDestination
Returns a new instance of DeidentifiedStoreDestination.
1443 1444 1445 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::HealthcareV1::DeidentifyConfig
Configures de-id options specific to different types of content. Each
submessage customizes the handling of an https://tools.ietf.org/html/rfc6838
media type or subtype. Configs are applied in a nested manner at runtime.
Corresponds to the JSON property config
1434 1435 1436 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1434 def config @config end |
#store ⇒ String
Optional. The full resource name of a Cloud Healthcare FHIR store, for example,
projects/project_id/locations/location_id/datasets/dataset_id/
fhirStores/fhir_store_id`.
Corresponds to the JSON propertystore`
1441 1442 1443 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1441 def store @store end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1448 1449 1450 1451 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1448 def update!(**args) @config = args[:config] if args.key?(:config) @store = args[:store] if args.key?(:store) end |