Class: Google::Apis::HealthcareV1::DeidentifiedStoreDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Contains configuration for streaming de-identified FHIR export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeidentifiedStoreDestination

Returns a new instance of DeidentifiedStoreDestination.



1392
1393
1394
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::HealthcareV1::DeidentifyConfig

Configures de-id options specific to different types of content. Each submessage customizes the handling of an https://tools.ietf.org/html/rfc6838 media type or subtype. Configs are applied in a nested manner at runtime. Corresponds to the JSON property config



1383
1384
1385
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1383

def config
  @config
end

#storeString

Optional. The full resource name of a Cloud Healthcare FHIR store, for example, projects/project_id/locations/location_id/datasets/dataset_id/ fhirStores/fhir_store_id`. Corresponds to the JSON propertystore`

Returns:

  • (String)


1390
1391
1392
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1390

def store
  @store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1397
1398
1399
1400
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1397

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @store = args[:store] if args.key?(:store)
end