Class: Google::Apis::HealthcareV1::DicomStoreMetrics
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::DicomStoreMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
DicomStoreMetrics contains metrics describing a DICOM store.
Instance Attribute Summary collapse
-
#blob_storage_size_bytes ⇒ Fixnum
Total blob storage bytes for all instances in the store.
-
#instance_count ⇒ Fixnum
Number of instances in the store.
-
#name ⇒ String
Resource name of the DICOM store, of the form
projects/project_id/locations/location_id/datasets/dataset_id/dicomStores/dicom_store_id``. -
#series_count ⇒ Fixnum
Number of series in the store.
-
#structured_storage_size_bytes ⇒ Fixnum
Total structured storage bytes for all instances in the store.
-
#study_count ⇒ Fixnum
Number of studies in the store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DicomStoreMetrics
constructor
A new instance of DicomStoreMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DicomStoreMetrics
Returns a new instance of DicomStoreMetrics.
1885 1886 1887 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_size_bytes ⇒ Fixnum
Total blob storage bytes for all instances in the store.
Corresponds to the JSON property blobStorageSizeBytes
1857 1858 1859 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1857 def blob_storage_size_bytes @blob_storage_size_bytes end |
#instance_count ⇒ Fixnum
Number of instances in the store.
Corresponds to the JSON property instanceCount
1862 1863 1864 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1862 def instance_count @instance_count end |
#name ⇒ String
Resource name of the DICOM store, of the form projects/project_id/locations/
location_id/datasets/dataset_id/dicomStores/dicom_store_id`.
Corresponds to the JSON propertyname`
1868 1869 1870 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1868 def name @name end |
#series_count ⇒ Fixnum
Number of series in the store.
Corresponds to the JSON property seriesCount
1873 1874 1875 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1873 def series_count @series_count end |
#structured_storage_size_bytes ⇒ Fixnum
Total structured storage bytes for all instances in the store.
Corresponds to the JSON property structuredStorageSizeBytes
1878 1879 1880 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1878 def structured_storage_size_bytes @structured_storage_size_bytes end |
#study_count ⇒ Fixnum
Number of studies in the store.
Corresponds to the JSON property studyCount
1883 1884 1885 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1883 def study_count @study_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1890 1891 1892 1893 1894 1895 1896 1897 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 1890 def update!(**args) @blob_storage_size_bytes = args[:blob_storage_size_bytes] if args.key?(:blob_storage_size_bytes) @instance_count = args[:instance_count] if args.key?(:instance_count) @name = args[:name] if args.key?(:name) @series_count = args[:series_count] if args.key?(:series_count) @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes) @study_count = args[:study_count] if args.key?(:study_count) end |