Class: Google::Apis::HealthcareV1::EvaluateUserConsentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Evaluate a user's Consents for all matching User data mappings. Note: User data mappings are indexed asynchronously, causing slight delays between the time mappings are created or updated and when they are included in EvaluateUserConsents results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvaluateUserConsentsRequest

Returns a new instance of EvaluateUserConsentsRequest.



2118
2119
2120
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of resource names of Consent resources. Corresponds to the JSON property consentList



2082
2083
2084
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2082

def consent_list
  @consent_list
end

#page_sizeFixnum

Optional. Limit on the number of User data mappings to return in a single response. If not specified, 100 is used. May not be larger than 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


2088
2089
2090
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2088

def page_size
  @page_size
end

#page_tokenString

Optional. Token to retrieve the next page of results, or empty to get the first page. Corresponds to the JSON property pageToken

Returns:

  • (String)


2094
2095
2096
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2094

def page_token
  @page_token
end

#request_attributesHash<String,String>

Required. The values of request attributes associated with this access request. Corresponds to the JSON property requestAttributes

Returns:

  • (Hash<String,String>)


2099
2100
2101
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2099

def request_attributes
  @request_attributes
end

#resource_attributesHash<String,String>

Optional. The values of resource attributes associated with the resources being requested. If no values are specified, then all resources are queried. Corresponds to the JSON property resourceAttributes

Returns:

  • (Hash<String,String>)


2105
2106
2107
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2105

def resource_attributes
  @resource_attributes
end

#response_viewString

Optional. The view for EvaluateUserConsentsResponse. If unspecified, defaults to BASIC and returns consented as TRUE or FALSE. Corresponds to the JSON property responseView

Returns:

  • (String)


2111
2112
2113
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2111

def response_view
  @response_view
end

#user_idString

Required. User ID to evaluate consents for. Corresponds to the JSON property userId

Returns:

  • (String)


2116
2117
2118
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2116

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2123
2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2123

def update!(**args)
  @consent_list = args[:consent_list] if args.key?(:consent_list)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @request_attributes = args[:request_attributes] if args.key?(:request_attributes)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
  @response_view = args[:response_view] if args.key?(:response_view)
  @user_id = args[:user_id] if args.key?(:user_id)
end