Class: Google::Apis::HealthcareV1::EvaluateUserConsentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::EvaluateUserConsentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#results ⇒ Array<Google::Apis::HealthcareV1::Result>
The consent evaluation result for each
data_id.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EvaluateUserConsentsResponse
constructor
A new instance of EvaluateUserConsentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EvaluateUserConsentsResponse
Returns a new instance of EvaluateUserConsentsResponse.
2155 2156 2157 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list. This token is valid for 72 hours after it is created.
Corresponds to the JSON property nextPageToken
2148 2149 2150 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2148 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::HealthcareV1::Result>
The consent evaluation result for each data_id.
Corresponds to the JSON property results
2153 2154 2155 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2153 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2160 2161 2162 2163 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2160 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |