Class: Google::Apis::HealthcareV1::EvaluateUserConsentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvaluateUserConsentsResponse

Returns a new instance of EvaluateUserConsentsResponse.



2098
2099
2100
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. This token is valid for 72 hours after it is created. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2091
2092
2093
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2091

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::HealthcareV1::Result>

The consent evaluation result for each data_id. Corresponds to the JSON property results



2096
2097
2098
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2096

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2103
2104
2105
2106
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2103

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
end