Class: Google::Apis::HealthcareV1::ExplainDataAccessConsentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

The enforcing consent's metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainDataAccessConsentInfo

Returns a new instance of ExplainDataAccessConsentInfo.



2157
2158
2159
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cascade_originsArray<String>

The compartment base resources that matched a cascading policy. Each resource has the following format: projects/project_id/locations/location_id/ datasets/dataset_id/fhirStores/fhir_store_id/fhir/resource_type/ resource_id` Corresponds to the JSON propertycascadeOrigins`

Returns:

  • (Array<String>)


2119
2120
2121
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2119

def cascade_origins
  @cascade_origins
end

The resource name of this consent resource, in the format: projects/ project_id/locations/location/datasets/dataset_id/fhirStores/ fhir_store_id/fhir/Consent/resource_id`. Corresponds to the JSON propertyconsentResource`

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2126

def consent_resource
  @consent_resource
end

#enforcement_timeString

Last enforcement timestamp of this consent resource. Corresponds to the JSON property enforcementTime

Returns:

  • (String)


2131
2132
2133
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2131

def enforcement_time
  @enforcement_time
end

#matching_accessor_scopesArray<Google::Apis::HealthcareV1::ConsentAccessorScope>

A list of all the matching accessor scopes of this consent policy that enforced ExplainDataAccessConsentScope.accessor_scope. Corresponds to the JSON property matchingAccessorScopes



2137
2138
2139
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2137

def matching_accessor_scopes
  @matching_accessor_scopes
end

The patient owning the consent (only applicable for patient consents), in the format: projects/project_id/locations/location_id/datasets/dataset_id/ fhirStores/fhir_store_id/fhir/Patient/patient_id` Corresponds to the JSON propertypatientConsentOwner`

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2144

def patient_consent_owner
  @patient_consent_owner
end

#typeString

The policy type of consent resource (e.g. PATIENT, ADMIN). Corresponds to the JSON property type

Returns:

  • (String)


2149
2150
2151
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2149

def type
  @type
end

#variantsArray<String>

The consent's variant combinations. A single consent may have multiple variants. Corresponds to the JSON property variants

Returns:

  • (Array<String>)


2155
2156
2157
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2155

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2162

def update!(**args)
  @cascade_origins = args[:cascade_origins] if args.key?(:cascade_origins)
  @consent_resource = args[:consent_resource] if args.key?(:consent_resource)
  @enforcement_time = args[:enforcement_time] if args.key?(:enforcement_time)
  @matching_accessor_scopes = args[:matching_accessor_scopes] if args.key?(:matching_accessor_scopes)
  @patient_consent_owner = args[:patient_consent_owner] if args.key?(:patient_consent_owner)
  @type = args[:type] if args.key?(:type)
  @variants = args[:variants] if args.key?(:variants)
end