Class: Google::Apis::HealthcareV1::ExplainDataAccessConsentScope
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ExplainDataAccessConsentScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
A single consent scope that provides info on who has access to the requested resource scope for a particular purpose and environment, enforced by which consent.
Instance Attribute Summary collapse
-
#accessor_scope ⇒ Google::Apis::HealthcareV1::ConsentAccessorScope
The accessor scope that describes who can access, for what purpose, in which environment.
-
#decision ⇒ String
Whether the current consent scope is permitted or denied access on the requested resource.
-
#enforcing_consents ⇒ Array<Google::Apis::HealthcareV1::ExplainDataAccessConsentInfo>
Metadata of the consent resources that enforce the consent scope's access.
-
#exceptions ⇒ Array<Google::Apis::HealthcareV1::ExplainDataAccessConsentScope>
Other consent scopes that created exceptions within this scope.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExplainDataAccessConsentScope
constructor
A new instance of ExplainDataAccessConsentScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExplainDataAccessConsentScope
Returns a new instance of ExplainDataAccessConsentScope.
2201 2202 2203 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accessor_scope ⇒ Google::Apis::HealthcareV1::ConsentAccessorScope
The accessor scope that describes who can access, for what purpose, in which
environment.
Corresponds to the JSON property accessorScope
2183 2184 2185 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2183 def accessor_scope @accessor_scope end |
#decision ⇒ String
Whether the current consent scope is permitted or denied access on the
requested resource.
Corresponds to the JSON property decision
2189 2190 2191 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2189 def decision @decision end |
#enforcing_consents ⇒ Array<Google::Apis::HealthcareV1::ExplainDataAccessConsentInfo>
Metadata of the consent resources that enforce the consent scope's access.
Corresponds to the JSON property enforcingConsents
2194 2195 2196 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2194 def @enforcing_consents end |
#exceptions ⇒ Array<Google::Apis::HealthcareV1::ExplainDataAccessConsentScope>
Other consent scopes that created exceptions within this scope.
Corresponds to the JSON property exceptions
2199 2200 2201 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2199 def exceptions @exceptions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2206 2207 2208 2209 2210 2211 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2206 def update!(**args) @accessor_scope = args[:accessor_scope] if args.key?(:accessor_scope) @decision = args[:decision] if args.key?(:decision) @enforcing_consents = args[:enforcing_consents] if args.key?(:enforcing_consents) @exceptions = args[:exceptions] if args.key?(:exceptions) end |