Class: Google::Apis::HealthcareV1::ExplainDataAccessResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

List of consent scopes that are applicable to the explained access on a given resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainDataAccessResponse

Returns a new instance of ExplainDataAccessResponse.



2282
2283
2284
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of applicable consent scopes. Sorted in order of actor such that scopes belonging to the same actor will be adjacent to each other in the list. Corresponds to the JSON property consentScopes



2274
2275
2276
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2274

def consent_scopes
  @consent_scopes
end

#warningString

Warnings associated with this response. It inform user with exceeded scope limit errors. Corresponds to the JSON property warning

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2280

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2287
2288
2289
2290
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2287

def update!(**args)
  @consent_scopes = args[:consent_scopes] if args.key?(:consent_scopes)
  @warning = args[:warning] if args.key?(:warning)
end