Class: Google::Apis::HealthcareV1::ExplainDataAccessResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ExplainDataAccessResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
List of consent scopes that are applicable to the explained access on a given resource.
Instance Attribute Summary collapse
-
#consent_scopes ⇒ Array<Google::Apis::HealthcareV1::ExplainDataAccessConsentScope>
List of applicable consent scopes.
-
#warning ⇒ String
Warnings associated with this response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExplainDataAccessResponse
constructor
A new instance of ExplainDataAccessResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExplainDataAccessResponse
Returns a new instance of ExplainDataAccessResponse.
2231 2232 2233 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_scopes ⇒ Array<Google::Apis::HealthcareV1::ExplainDataAccessConsentScope>
List of applicable consent scopes. Sorted in order of actor such that scopes
belonging to the same actor will be adjacent to each other in the list.
Corresponds to the JSON property consentScopes
2223 2224 2225 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2223 def @consent_scopes end |
#warning ⇒ String
Warnings associated with this response. It inform user with exceeded scope
limit errors.
Corresponds to the JSON property warning
2229 2230 2231 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2229 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2236 2237 2238 2239 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2236 def update!(**args) @consent_scopes = args[:consent_scopes] if args.key?(:consent_scopes) @warning = args[:warning] if args.key?(:warning) end |