Class: Google::Apis::HealthcareV1::ExportDicomDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Exports data from the specified DICOM store. If a given resource, such as a DICOM object with the same SOPInstance UID, already exists in the output, it is overwritten with the version in the source dataset. Exported DICOM data persists when the DICOM store from which it was exported is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportDicomDataRequest

Returns a new instance of ExportDicomDataRequest.



2311
2312
2313
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomBigQueryDestination

The BigQuery table where the server writes the output. Corresponds to the JSON property bigqueryDestination



2303
2304
2305
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2303

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsDestination

The Cloud Storage location where the server writes the output and the export configuration. Corresponds to the JSON property gcsDestination



2309
2310
2311
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2309

def gcs_destination
  @gcs_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2316
2317
2318
2319
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2316

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
end