Class: Google::Apis::HealthcareV1::ExportDicomDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Exports data from the specified DICOM store. If a given resource, such as a DICOM object with the same SOPInstance UID, already exists in the output, it is overwritten with the version in the source dataset. Exported DICOM data persists when the DICOM store from which it was exported is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportDicomDataRequest

Returns a new instance of ExportDicomDataRequest.



2260
2261
2262
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomBigQueryDestination

The BigQuery table where the server writes the output. Corresponds to the JSON property bigqueryDestination



2252
2253
2254
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2252

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsDestination

The Cloud Storage location where the server writes the output and the export configuration. Corresponds to the JSON property gcsDestination



2258
2259
2260
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2258

def gcs_destination
  @gcs_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2265
2266
2267
2268
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2265

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
end