Class: Google::Apis::HealthcareV1::FhirNotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::FhirNotificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Contains the configuration for FHIR notifications.
Instance Attribute Summary collapse
-
#pubsub_topic ⇒ String
Optional.
-
#send_full_resource ⇒ Boolean
(also: #send_full_resource?)
Optional.
-
#send_previous_resource_on_delete ⇒ Boolean
(also: #send_previous_resource_on_delete?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirNotificationConfig
constructor
A new instance of FhirNotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirNotificationConfig
Returns a new instance of FhirNotificationConfig.
2672 2673 2674 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pubsub_topic ⇒ String
Optional. The Pub/Sub topic that
notifications of changes are published on. Supplied by the client. The
notification is a PubsubMessage with the following fields: * PubsubMessage.
Data contains the resource name. * PubsubMessage.MessageId is the ID of
this notification. It is guaranteed to be unique within the topic. *
PubsubMessage.PublishTime is the time when the message was published. Note
that notifications are only sent if the topic is non-empty. Topic names must be scoped to a
project. The Cloud Healthcare API service account, service-@gcp-sa-healthcare.
iam.gserviceaccount.com, must have publisher permissions on the given Pub/Sub
topic. Not having adequate permissions causes the calls that send
notifications to fail (https://cloud.google.com/healthcare-api/docs/
permissions-healthcare-api-gcp-products#
dicom_fhir_and_hl7v2_store_cloud_pubsub_permissions). If a notification can't
be published to Pub/Sub, errors are logged to Cloud Logging. For more
information, see Viewing error logs in Cloud Logging.
Corresponds to the JSON property pubsubTopic
2651 2652 2653 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2651 def pubsub_topic @pubsub_topic end |
#send_full_resource ⇒ Boolean Also known as: send_full_resource?
Optional. Whether to send full FHIR resource to this Pub/Sub topic. The
default value is false.
Corresponds to the JSON property sendFullResource
2657 2658 2659 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2657 def send_full_resource @send_full_resource end |
#send_previous_resource_on_delete ⇒ Boolean Also known as: send_previous_resource_on_delete?
Optional. Whether to send full FHIR resource to this Pub/Sub topic for
deleting FHIR resource. The default value is false. Note that setting this to
true does not guarantee that all previous resources will be sent in the format
of full FHIR resource. When a resource change is too large or during heavy
traffic, only the resource name will be sent. Clients should always check the "
payloadType" label from a Pub/Sub message to determine whether it needs to
fetch the full previous resource as a separate operation.
Corresponds to the JSON property sendPreviousResourceOnDelete
2669 2670 2671 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2669 def send_previous_resource_on_delete @send_previous_resource_on_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2677 2678 2679 2680 2681 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2677 def update!(**args) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @send_full_resource = args[:send_full_resource] if args.key?(:send_full_resource) @send_previous_resource_on_delete = args[:send_previous_resource_on_delete] if args.key?(:send_previous_resource_on_delete) end |