Class: Google::Apis::HealthcareV1::FhirStore
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::FhirStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Represents a FHIR store.
Instance Attribute Summary collapse
-
#bulk_export_gcs_destination ⇒ Google::Apis::HealthcareV1::BulkExportGcsDestination
The configuration for exporting to Cloud Storage using the bulk export API.
-
#complex_data_type_reference_parsing ⇒ String
Optional.
-
#consent_config ⇒ Google::Apis::HealthcareV1::ConsentConfig
Configures whether to enforce consent for the FHIR store and which consent enforcement version is being used.
-
#default_search_handling_strict ⇒ Boolean
(also: #default_search_handling_strict?)
Optional.
-
#disable_referential_integrity ⇒ Boolean
(also: #disable_referential_integrity?)
Immutable.
-
#disable_resource_versioning ⇒ Boolean
(also: #disable_resource_versioning?)
Immutable.
-
#enable_update_create ⇒ Boolean
(also: #enable_update_create?)
Optional.
-
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize FHIR stores.
-
#name ⇒ String
Output only.
-
#notification_config ⇒ Google::Apis::HealthcareV1::NotificationConfig
Specifies where to send notifications upon changes to a data store.
-
#notification_configs ⇒ Array<Google::Apis::HealthcareV1::FhirNotificationConfig>
Optional.
-
#stream_configs ⇒ Array<Google::Apis::HealthcareV1::StreamConfig>
Optional.
-
#validation_config ⇒ Google::Apis::HealthcareV1::ValidationConfig
Contains the configuration for FHIR profiles and validation.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirStore
constructor
A new instance of FhirStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirStore
Returns a new instance of FhirStore.
2766 2767 2768 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulk_export_gcs_destination ⇒ Google::Apis::HealthcareV1::BulkExportGcsDestination
The configuration for exporting to Cloud Storage using the bulk export API.
Corresponds to the JSON property bulkExportGcsDestination
2640 2641 2642 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2640 def bulk_export_gcs_destination @bulk_export_gcs_destination end |
#complex_data_type_reference_parsing ⇒ String
Optional. Enable parsing of references within complex FHIR data types such as
Extensions. If this value is set to ENABLED, then features like referential
integrity and Bundle reference rewriting apply to all references. If this flag
has not been specified the behavior of the FHIR store will not change,
references in complex data types will not be parsed. New stores will have this
value set to ENABLED after a notification period. Warning: turning on this
flag causes processing existing resources to fail if they contain references
to non-existent resources. Cannot be disabled in R5.
Corresponds to the JSON property complexDataTypeReferenceParsing
2652 2653 2654 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2652 def complex_data_type_reference_parsing @complex_data_type_reference_parsing end |
#consent_config ⇒ Google::Apis::HealthcareV1::ConsentConfig
Configures whether to enforce consent for the FHIR store and which consent
enforcement version is being used.
Corresponds to the JSON property consentConfig
2658 2659 2660 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2658 def @consent_config end |
#default_search_handling_strict ⇒ Boolean Also known as: default_search_handling_strict?
Optional. If true, overrides the default search behavior for this FHIR store
to handling=strict which returns an error for unrecognized search parameters.
If false, uses the FHIR specification default handling=lenient which
ignores unrecognized search parameters. The handling can always be changed
from the default on an individual API call by setting the HTTP header Prefer:
handling=strict or Prefer: handling=lenient. Defaults to false.
Corresponds to the JSON property defaultSearchHandlingStrict
2668 2669 2670 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2668 def default_search_handling_strict @default_search_handling_strict end |
#disable_referential_integrity ⇒ Boolean Also known as: disable_referential_integrity?
Immutable. Whether to disable referential integrity in this FHIR store. This
field is immutable after FHIR store creation. The default value is false,
meaning that the API enforces referential integrity and fails the requests
that result in inconsistent state in the FHIR store. When this field is set to
true, the API skips referential integrity checks. Consequently, operations
that rely on references, such as GetPatientEverything, do not return all the
results if broken references exist.
Corresponds to the JSON property disableReferentialIntegrity
2680 2681 2682 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2680 def disable_referential_integrity @disable_referential_integrity end |
#disable_resource_versioning ⇒ Boolean Also known as: disable_resource_versioning?
Immutable. Whether to disable resource versioning for this FHIR store. This
field can not be changed after the creation of FHIR store. If set to false,
all write operations cause historical versions to be recorded automatically.
The historical versions can be fetched through the history APIs, but cannot be
updated. If set to true, no historical versions are kept. The server sends
errors for attempts to read the historical versions. Defaults to false.
Corresponds to the JSON property disableResourceVersioning
2691 2692 2693 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2691 def disable_resource_versioning @disable_resource_versioning end |
#enable_update_create ⇒ Boolean Also known as: enable_update_create?
Optional. Whether this FHIR store has the updateCreate capability. This determines if the client can use an Update
operation to create a new resource with a client-specified ID. If false, all
IDs are server-assigned through the Create operation and attempts to update a
non-existent resource return errors. It is strongly advised not to include or
encode any sensitive data such as patient identifiers in client-specified
resource IDs. Those IDs are part of the FHIR resource path recorded in Cloud
audit logs and Pub/Sub notifications. Those IDs can also be contained in
reference fields within other resources. Defaults to false.
Corresponds to the JSON property enableUpdateCreate
2706 2707 2708 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2706 def enable_update_create @enable_update_create end |
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize FHIR stores. Label keys must be
between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
and must conform to the following PCRE regular expression: \pLl\pLo0,62
Label values are optional, must be between 1 and 63 characters long, have a
UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE
regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be
associated with a given store.
Corresponds to the JSON property labels
2718 2719 2720 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2718 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of the FHIR store, of the form
projects/project_id/locations/location/datasets/dataset_id/fhirStores/
fhir_store_id`.
Corresponds to the JSON propertyname`
2725 2726 2727 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2725 def name @name end |
#notification_config ⇒ Google::Apis::HealthcareV1::NotificationConfig
Specifies where to send notifications upon changes to a data store.
Corresponds to the JSON property notificationConfig
2730 2731 2732 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2730 def notification_config @notification_config end |
#notification_configs ⇒ Array<Google::Apis::HealthcareV1::FhirNotificationConfig>
Optional. Specifies where and whether to send notifications upon changes to a
FHIR store.
Corresponds to the JSON property notificationConfigs
2736 2737 2738 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2736 def notification_configs @notification_configs end |
#stream_configs ⇒ Array<Google::Apis::HealthcareV1::StreamConfig>
Optional. A list of streaming configs that configure the destinations of
streaming export for every resource mutation in this FHIR store. Each store is
allowed to have up to 10 streaming configs. After a new config is added, the
next resource mutation is streamed to the new location in addition to the
existing ones. When a location is removed from the list, the server stops
streaming to that location. Before adding a new config, you must add the
required bigquery.dataEditor role to your project's Cloud Healthcare Service
Agent service account.
Some lag (typically on the order of dozens of seconds) is expected before the
results show up in the streaming destination.
Corresponds to the JSON property streamConfigs
2751 2752 2753 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2751 def stream_configs @stream_configs end |
#validation_config ⇒ Google::Apis::HealthcareV1::ValidationConfig
Contains the configuration for FHIR profiles and validation.
Corresponds to the JSON property validationConfig
2756 2757 2758 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2756 def validation_config @validation_config end |
#version ⇒ String
Required. Immutable. The FHIR specification version that this FHIR store
supports natively. This field is immutable after store creation. Requests are
rejected if they contain FHIR resources of a different version. Version is
required for every FHIR store.
Corresponds to the JSON property version
2764 2765 2766 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2764 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2771 def update!(**args) @bulk_export_gcs_destination = args[:bulk_export_gcs_destination] if args.key?(:bulk_export_gcs_destination) @complex_data_type_reference_parsing = args[:complex_data_type_reference_parsing] if args.key?(:complex_data_type_reference_parsing) @consent_config = args[:consent_config] if args.key?(:consent_config) @default_search_handling_strict = args[:default_search_handling_strict] if args.key?(:default_search_handling_strict) @disable_referential_integrity = args[:disable_referential_integrity] if args.key?(:disable_referential_integrity) @disable_resource_versioning = args[:disable_resource_versioning] if args.key?(:disable_resource_versioning) @enable_update_create = args[:enable_update_create] if args.key?(:enable_update_create) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notification_config = args[:notification_config] if args.key?(:notification_config) @notification_configs = args[:notification_configs] if args.key?(:notification_configs) @stream_configs = args[:stream_configs] if args.key?(:stream_configs) @validation_config = args[:validation_config] if args.key?(:validation_config) @version = args[:version] if args.key?(:version) end |