Class: Google::Apis::HealthcareV1::FhirStoreMetric
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::FhirStoreMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Count of resources and total storage size by type for a given FHIR store.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The total count of FHIR resources in the store of this resource type.
-
#resource_type ⇒ String
The FHIR resource type this metric applies to.
-
#structured_storage_size_bytes ⇒ Fixnum
The total amount of structured storage used by FHIR resources of this resource type in the store.
-
#versioned_storage_size_bytes ⇒ Fixnum
The total amount of versioned storage used by versioned FHIR resources of this resource type in the store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirStoreMetric
constructor
A new instance of FhirStoreMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirStoreMetric
Returns a new instance of FhirStoreMetric.
2815 2816 2817 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The total count of FHIR resources in the store of this resource type.
Corresponds to the JSON property count
2796 2797 2798 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2796 def count @count end |
#resource_type ⇒ String
The FHIR resource type this metric applies to.
Corresponds to the JSON property resourceType
2801 2802 2803 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2801 def resource_type @resource_type end |
#structured_storage_size_bytes ⇒ Fixnum
The total amount of structured storage used by FHIR resources of this resource
type in the store.
Corresponds to the JSON property structuredStorageSizeBytes
2807 2808 2809 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2807 def structured_storage_size_bytes @structured_storage_size_bytes end |
#versioned_storage_size_bytes ⇒ Fixnum
The total amount of versioned storage used by versioned FHIR resources of this
resource type in the store.
Corresponds to the JSON property versionedStorageSizeBytes
2813 2814 2815 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2813 def versioned_storage_size_bytes @versioned_storage_size_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2820 2821 2822 2823 2824 2825 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 2820 def update!(**args) @count = args[:count] if args.key?(:count) @resource_type = args[:resource_type] if args.key?(:resource_type) @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes) @versioned_storage_size_bytes = args[:versioned_storage_size_bytes] if args.key?(:versioned_storage_size_bytes) end |