Class: Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomBigQueryDestination
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomBigQueryDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
The BigQuery table where the server writes the output.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#include_source_store ⇒ Boolean
(also: #include_source_store?)
Optional.
-
#schema_flattened ⇒ Google::Apis::HealthcareV1::SchemaFlattened
Using this field will flatten the DICOM instances into a BigQuery table.
-
#schema_json ⇒ Google::Apis::HealthcareV1::SchemaJson
Using this field will set the schema such that all DICOM tags will be included in the BigQuery table as a single JSON type column.
-
#table_uri ⇒ String
Optional.
-
#write_disposition ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudHealthcareV1DicomBigQueryDestination
constructor
A new instance of GoogleCloudHealthcareV1DicomBigQueryDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudHealthcareV1DicomBigQueryDestination
Returns a new instance of GoogleCloudHealthcareV1DicomBigQueryDestination.
3198 3199 3200 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. Use write_disposition instead. If write_disposition is specified,
this parameter is ignored. force=false is equivalent to write_disposition=
WRITE_EMPTY and force=true is equivalent to write_disposition=WRITE_TRUNCATE.
Corresponds to the JSON property force
3149 3150 3151 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3149 def force @force end |
#include_source_store ⇒ Boolean Also known as: include_source_store?
Optional. If true, the source store name will be included as a column in the
BigQuery schema.
Corresponds to the JSON property includeSourceStore
3156 3157 3158 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3156 def include_source_store @include_source_store end |
#schema_flattened ⇒ Google::Apis::HealthcareV1::SchemaFlattened
Using this field will flatten the DICOM instances into a BigQuery table. The
table will have one column for each DICOM tag. The column name will be the
DICOM tag's textual representation.
Corresponds to the JSON property schemaFlattened
3164 3165 3166 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3164 def schema_flattened @schema_flattened end |
#schema_json ⇒ Google::Apis::HealthcareV1::SchemaJson
Using this field will set the schema such that all DICOM tags will be included
in the BigQuery table as a single JSON type column. The BigQuery table schema
will include the following columns: * StudyInstanceUID (Type: STRING): DICOM
Tag 0020000D. * SeriesInstanceUID (Type: STRING): DICOM Tag 0020000E. *
SOPInstanceUID (Type: STRING): DICOM Tag 00080018. * SourceDicomStore (Type:
STRING): The name of the source DICOM store. This field is only included if
the include_source_store option is set to true. * Metadata (Type: JSON):
All DICOM tags for the instance, stored in a single JSON object. *
StructuredStorageSize (Type: INTEGER): Size of the structured storage in
bytes. * DroppedTags (Type: STRING, Repeated: Yes): List of tags that were
dropped during the conversion. * StorageClass (Type: STRING): The storage
class of the instance. * LastUpdated (Type: TIMESTAMP): Timestamp of the
last update to the instance. * BlobStorageSize (Type: INTEGER): Size of the
blob storage in bytes. * Type (Type: STRING): Indicates the type of
operation (e.g., INSERT, DELETE).
Corresponds to the JSON property schemaJson
3183 3184 3185 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3183 def schema_json @schema_json end |
#table_uri ⇒ String
Optional. BigQuery URI to a table, up to 2000 characters long, in the format
bq://projectId.bqDatasetId.tableId
Corresponds to the JSON property tableUri
3189 3190 3191 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3189 def table_uri @table_uri end |
#write_disposition ⇒ String
Optional. Determines whether the existing table in the destination is to be
overwritten or appended to. If a write_disposition is specified, the force
parameter is ignored.
Corresponds to the JSON property writeDisposition
3196 3197 3198 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3196 def write_disposition @write_disposition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3203 3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3203 def update!(**args) @force = args[:force] if args.key?(:force) @include_source_store = args[:include_source_store] if args.key?(:include_source_store) @schema_flattened = args[:schema_flattened] if args.key?(:schema_flattened) @schema_json = args[:schema_json] if args.key?(:schema_json) @table_uri = args[:table_uri] if args.key?(:table_uri) @write_disposition = args[:write_disposition] if args.key?(:write_disposition) end |