Class: Google::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirBigQueryDestination
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirBigQueryDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
The configuration for exporting to BigQuery.
Instance Attribute Summary collapse
-
#dataset_uri ⇒ String
Optional.
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#schema_config ⇒ Google::Apis::HealthcareV1::SchemaConfig
Configuration for the FHIR BigQuery schema.
-
#write_disposition ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudHealthcareV1FhirBigQueryDestination
constructor
A new instance of GoogleCloudHealthcareV1FhirBigQueryDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudHealthcareV1FhirBigQueryDestination
Returns a new instance of GoogleCloudHealthcareV1FhirBigQueryDestination.
3370 3371 3372 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_uri ⇒ String
Optional. BigQuery URI to an existing dataset, up to 2000 characters long, in
the format bq://projectId.bqDatasetId.
Corresponds to the JSON property datasetUri
3344 3345 3346 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3344 def dataset_uri @dataset_uri end |
#force ⇒ Boolean Also known as: force?
Optional. The default value is false. If this flag is TRUE, all tables are
deleted from the dataset before the new exported tables are written. If the
flag is not set and the destination dataset contains tables, the export call
returns an error. If write_disposition is specified, this parameter is
ignored. force=false is equivalent to write_disposition=WRITE_EMPTY and force=
true is equivalent to write_disposition=WRITE_TRUNCATE.
Corresponds to the JSON property force
3354 3355 3356 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3354 def force @force end |
#schema_config ⇒ Google::Apis::HealthcareV1::SchemaConfig
Configuration for the FHIR BigQuery schema. Determines how the server
generates the schema.
Corresponds to the JSON property schemaConfig
3361 3362 3363 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3361 def schema_config @schema_config end |
#write_disposition ⇒ String
Optional. Determines if existing data in the destination dataset is
overwritten, appended to, or not written if the tables contain data. If a
write_disposition is specified, the force parameter is ignored.
Corresponds to the JSON property writeDisposition
3368 3369 3370 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3368 def write_disposition @write_disposition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3375 3376 3377 3378 3379 3380 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3375 def update!(**args) @dataset_uri = args[:dataset_uri] if args.key?(:dataset_uri) @force = args[:force] if args.key?(:force) @schema_config = args[:schema_config] if args.key?(:schema_config) @write_disposition = args[:write_disposition] if args.key?(:write_disposition) end |