Class: Google::Apis::HealthcareV1::GoogleCloudHealthcareV1FhirBigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

The configuration for exporting to BigQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1FhirBigQueryDestination

Returns a new instance of GoogleCloudHealthcareV1FhirBigQueryDestination.



3256
3257
3258
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_uriString

Optional. BigQuery URI to an existing dataset, up to 2000 characters long, in the format bq://projectId.bqDatasetId. Corresponds to the JSON property datasetUri

Returns:

  • (String)


3230
3231
3232
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3230

def dataset_uri
  @dataset_uri
end

#forceBoolean Also known as: force?

Optional. The default value is false. If this flag is TRUE, all tables are deleted from the dataset before the new exported tables are written. If the flag is not set and the destination dataset contains tables, the export call returns an error. If write_disposition is specified, this parameter is ignored. force=false is equivalent to write_disposition=WRITE_EMPTY and force= true is equivalent to write_disposition=WRITE_TRUNCATE. Corresponds to the JSON property force

Returns:

  • (Boolean)


3240
3241
3242
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3240

def force
  @force
end

#schema_configGoogle::Apis::HealthcareV1::SchemaConfig

Configuration for the FHIR BigQuery schema. Determines how the server generates the schema. Corresponds to the JSON property schemaConfig



3247
3248
3249
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3247

def schema_config
  @schema_config
end

#write_dispositionString

Optional. Determines if existing data in the destination dataset is overwritten, appended to, or not written if the tables contain data. If a write_disposition is specified, the force parameter is ignored. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


3254
3255
3256
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3254

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3261
3262
3263
3264
3265
3266
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3261

def update!(**args)
  @dataset_uri = args[:dataset_uri] if args.key?(:dataset_uri)
  @force = args[:force] if args.key?(:force)
  @schema_config = args[:schema_config] if args.key?(:schema_config)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end