Class: Google::Apis::HealthcareV1::Hl7V2Store
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::Hl7V2Store
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Represents an HL7v2 store.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize HL7v2 stores.
-
#name ⇒ String
Identifier.
-
#notification_configs ⇒ Array<Google::Apis::HealthcareV1::Hl7V2NotificationConfig>
Optional.
-
#parser_config ⇒ Google::Apis::HealthcareV1::ParserConfig
The configuration for the parser.
-
#reject_duplicate_message ⇒ Boolean
(also: #reject_duplicate_message?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Hl7V2Store
constructor
A new instance of Hl7V2Store.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Hl7V2Store
Returns a new instance of Hl7V2Store.
3634 3635 3636 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize HL7v2 stores. Label keys must
be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128
bytes, and must conform to the following PCRE regular expression: \pLl\pLo
0,62 Label values are optional, must be between 1 and 63 characters long,
have a UTF-8 encoding of maximum 128 bytes, and must conform to the following
PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels
can be associated with a given store.
Corresponds to the JSON property labels
3597 3598 3599 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3597 def labels @labels end |
#name ⇒ String
Identifier. Resource name of the HL7v2 store, of the form projects/
project_id/locations/location_id/datasets/dataset_id/hl7V2Stores/
hl7v2_store_id`.
Corresponds to the JSON propertyname`
3604 3605 3606 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3604 def name @name end |
#notification_configs ⇒ Array<Google::Apis::HealthcareV1::Hl7V2NotificationConfig>
Optional. A list of notification configs. Each configuration uses a filter to
determine whether to publish a message (both Ingest & Create) on the
corresponding notification destination. Only the message name is sent as part
of the notification. Supplied by the client.
Corresponds to the JSON property notificationConfigs
3612 3613 3614 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3612 def notification_configs @notification_configs end |
#parser_config ⇒ Google::Apis::HealthcareV1::ParserConfig
The configuration for the parser. It determines how the server parses the
messages.
Corresponds to the JSON property parserConfig
3618 3619 3620 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3618 def parser_config @parser_config end |
#reject_duplicate_message ⇒ Boolean Also known as: reject_duplicate_message?
Optional. Determines whether to reject duplicate messages. A duplicate message
is a message with the same raw bytes as a message that has already been
ingested/created in this HL7v2 store. The default value is false, meaning that
the store accepts the duplicate messages and it also returns the same ACK
message in the IngestMessageResponse as has been returned previously. Note
that only one resource is created in the store. When this field is set to true,
CreateMessage/IngestMessage requests with a duplicate message will be
rejected by the store, and IngestMessageErrorDetail returns a NACK message
upon rejection.
Corresponds to the JSON property rejectDuplicateMessage
3631 3632 3633 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3631 def @reject_duplicate_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3639 3640 3641 3642 3643 3644 3645 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3639 def update!(**args) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notification_configs = args[:notification_configs] if args.key?(:notification_configs) @parser_config = args[:parser_config] if args.key?(:parser_config) @reject_duplicate_message = args[:reject_duplicate_message] if args.key?(:reject_duplicate_message) end |