Class: Google::Apis::HealthcareV1::Hl7V2Store

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Represents an HL7v2 store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Hl7V2Store

Returns a new instance of Hl7V2Store.



3526
3527
3528
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

User-supplied key-value pairs used to organize HL7v2 stores. Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: \pLl\pLo 0,62 Label values are optional, must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be associated with a given store. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3489
3490
3491
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3489

def labels
  @labels
end

#nameString

Identifier. Resource name of the HL7v2 store, of the form projects/ project_id/locations/location_id/datasets/dataset_id/hl7V2Stores/ hl7v2_store_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


3496
3497
3498
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3496

def name
  @name
end

#notification_configsArray<Google::Apis::HealthcareV1::Hl7V2NotificationConfig>

Optional. A list of notification configs. Each configuration uses a filter to determine whether to publish a message (both Ingest & Create) on the corresponding notification destination. Only the message name is sent as part of the notification. Supplied by the client. Corresponds to the JSON property notificationConfigs



3504
3505
3506
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3504

def notification_configs
  @notification_configs
end

#parser_configGoogle::Apis::HealthcareV1::ParserConfig

The configuration for the parser. It determines how the server parses the messages. Corresponds to the JSON property parserConfig



3510
3511
3512
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3510

def parser_config
  @parser_config
end

#reject_duplicate_messageBoolean Also known as: reject_duplicate_message?

Optional. Determines whether to reject duplicate messages. A duplicate message is a message with the same raw bytes as a message that has already been ingested/created in this HL7v2 store. The default value is false, meaning that the store accepts the duplicate messages and it also returns the same ACK message in the IngestMessageResponse as has been returned previously. Note that only one resource is created in the store. When this field is set to true, CreateMessage/IngestMessage requests with a duplicate message will be rejected by the store, and IngestMessageErrorDetail returns a NACK message upon rejection. Corresponds to the JSON property rejectDuplicateMessage

Returns:

  • (Boolean)


3523
3524
3525
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3523

def reject_duplicate_message
  @reject_duplicate_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3531
3532
3533
3534
3535
3536
3537
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3531

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notification_configs = args[:notification_configs] if args.key?(:notification_configs)
  @parser_config = args[:parser_config] if args.key?(:parser_config)
  @reject_duplicate_message = args[:reject_duplicate_message] if args.key?(:reject_duplicate_message)
end