Class: Google::Apis::HealthcareV1::ImportDicomDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ImportDicomDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Imports data into the specified DICOM store. Returns an error if any of the files to import are not DICOM files. This API accepts duplicate DICOM instances by ignoring the newly-pushed instance. It does not overwrite.
Instance Attribute Summary collapse
-
#blob_storage_settings ⇒ Google::Apis::HealthcareV1::BlobStorageSettings
Settings for data stored in Blob storage.
-
#gcs_source ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsSource
Specifies the configuration for importing data from Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportDicomDataRequest
constructor
A new instance of ImportDicomDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportDicomDataRequest
Returns a new instance of ImportDicomDataRequest.
3715 3716 3717 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_settings ⇒ Google::Apis::HealthcareV1::BlobStorageSettings
Settings for data stored in Blob storage.
Corresponds to the JSON property blobStorageSettings
3708 3709 3710 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3708 def blob_storage_settings @blob_storage_settings end |
#gcs_source ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1DicomGcsSource
Specifies the configuration for importing data from Cloud Storage.
Corresponds to the JSON property gcsSource
3713 3714 3715 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3713 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3720 3721 3722 3723 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3720 def update!(**args) @blob_storage_settings = args[:blob_storage_settings] if args.key?(:blob_storage_settings) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |