Class: Google::Apis::HealthcareV1::ImportMessagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ImportMessagesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Final response of importing messages. This structure is included in the response to describe the detailed outcome. It is only included when the operation finishes successfully.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportMessagesResponse
constructor
A new instance of ImportMessagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportMessagesResponse
Returns a new instance of ImportMessagesResponse.
3872 3873 3874 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3872 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3877 3878 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 3877 def update!(**args) end |