Class: Google::Apis::HealthcareV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
OperationMetadata provides information about the operation execution. Returned in the long-running operation's metadata field.
Instance Attribute Summary collapse
-
#api_method_name ⇒ String
The name of the API method that initiated the operation.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Specifies if cancellation was requested for the operation.
-
#counter ⇒ Google::Apis::HealthcareV1::ProgressCounter
ProgressCounter provides counters to describe an operation's progress.
-
#create_time ⇒ String
The time at which the operation was created by the API.
-
#end_time ⇒ String
The time at which execution was completed.
-
#logs_url ⇒ String
A link to audit and error logs in the log viewer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
4715 4716 4717 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_method_name ⇒ String
The name of the API method that initiated the operation.
Corresponds to the JSON property apiMethodName
4685 4686 4687 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4685 def api_method_name @api_method_name end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Specifies if cancellation was requested for the operation.
Corresponds to the JSON property cancelRequested
4690 4691 4692 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4690 def cancel_requested @cancel_requested end |
#counter ⇒ Google::Apis::HealthcareV1::ProgressCounter
ProgressCounter provides counters to describe an operation's progress.
Corresponds to the JSON property counter
4696 4697 4698 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4696 def counter @counter end |
#create_time ⇒ String
The time at which the operation was created by the API.
Corresponds to the JSON property createTime
4701 4702 4703 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4701 def create_time @create_time end |
#end_time ⇒ String
The time at which execution was completed.
Corresponds to the JSON property endTime
4706 4707 4708 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4706 def end_time @end_time end |
#logs_url ⇒ String
A link to audit and error logs in the log viewer. Error logs are generated
only by some operations, listed at Viewing error logs in Cloud Logging.
Corresponds to the JSON property logsUrl
4713 4714 4715 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4713 def logs_url @logs_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4720 4721 4722 4723 4724 4725 4726 4727 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4720 def update!(**args) @api_method_name = args[:api_method_name] if args.key?(:api_method_name) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @counter = args[:counter] if args.key?(:counter) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @logs_url = args[:logs_url] if args.key?(:logs_url) end |