Class: Google::Apis::HealthcareV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

OperationMetadata provides information about the operation execution. Returned in the long-running operation's metadata field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



4709
4710
4711
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_method_nameString

The name of the API method that initiated the operation. Corresponds to the JSON property apiMethodName

Returns:

  • (String)


4679
4680
4681
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4679

def api_method_name
  @api_method_name
end

#cancel_requestedBoolean Also known as: cancel_requested?

Specifies if cancellation was requested for the operation. Corresponds to the JSON property cancelRequested

Returns:

  • (Boolean)


4684
4685
4686
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4684

def cancel_requested
  @cancel_requested
end

#counterGoogle::Apis::HealthcareV1::ProgressCounter

ProgressCounter provides counters to describe an operation's progress. Corresponds to the JSON property counter



4690
4691
4692
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4690

def counter
  @counter
end

#create_timeString

The time at which the operation was created by the API. Corresponds to the JSON property createTime

Returns:

  • (String)


4695
4696
4697
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4695

def create_time
  @create_time
end

#end_timeString

The time at which execution was completed. Corresponds to the JSON property endTime

Returns:

  • (String)


4700
4701
4702
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4700

def end_time
  @end_time
end

#logs_urlString

A link to audit and error logs in the log viewer. Error logs are generated only by some operations, listed at Viewing error logs in Cloud Logging. Corresponds to the JSON property logsUrl

Returns:

  • (String)


4707
4708
4709
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4707

def logs_url
  @logs_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4714
4715
4716
4717
4718
4719
4720
4721
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4714

def update!(**args)
  @api_method_name = args[:api_method_name] if args.key?(:api_method_name)
  @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested)
  @counter = args[:counter] if args.key?(:counter)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @logs_url = args[:logs_url] if args.key?(:logs_url)
end