Class: Google::Apis::HealthcareV1::ProgressCounter
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ProgressCounter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
ProgressCounter provides counters to describe an operation's progress.
Instance Attribute Summary collapse
-
#failure ⇒ Fixnum
The number of units that failed in the operation.
-
#pending ⇒ Fixnum
The number of units that are pending in the operation.
-
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
-
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
-
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProgressCounter
constructor
A new instance of ProgressCounter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProgressCounter
Returns a new instance of ProgressCounter.
4962 4963 4964 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure ⇒ Fixnum
The number of units that failed in the operation.
Corresponds to the JSON property failure
4940 4941 4942 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4940 def failure @failure end |
#pending ⇒ Fixnum
The number of units that are pending in the operation.
Corresponds to the JSON property pending
4945 4946 4947 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4945 def pending @pending end |
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
Corresponds to the JSON property secondaryFailure
4950 4951 4952 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4950 def secondary_failure @secondary_failure end |
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
Corresponds to the JSON property secondarySuccess
4955 4956 4957 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4955 def secondary_success @secondary_success end |
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Corresponds to the JSON property success
4960 4961 4962 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4960 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4967 4968 4969 4970 4971 4972 4973 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4967 def update!(**args) @failure = args[:failure] if args.key?(:failure) @pending = args[:pending] if args.key?(:pending) @secondary_failure = args[:secondary_failure] if args.key?(:secondary_failure) @secondary_success = args[:secondary_success] if args.key?(:secondary_success) @success = args[:success] if args.key?(:success) end |