Class: Google::Apis::HealthcareV1::ProgressCounter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

ProgressCounter provides counters to describe an operation's progress.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProgressCounter

Returns a new instance of ProgressCounter.



4956
4957
4958
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failureFixnum

The number of units that failed in the operation. Corresponds to the JSON property failure

Returns:

  • (Fixnum)


4934
4935
4936
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4934

def failure
  @failure
end

#pendingFixnum

The number of units that are pending in the operation. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


4939
4940
4941
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4939

def pending
  @pending
end

#secondary_failureFixnum

The number of secondary units that failed in the operation. Corresponds to the JSON property secondaryFailure

Returns:

  • (Fixnum)


4944
4945
4946
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4944

def secondary_failure
  @secondary_failure
end

#secondary_successFixnum

The number of secondary units that succeeded in the operation. Corresponds to the JSON property secondarySuccess

Returns:

  • (Fixnum)


4949
4950
4951
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4949

def secondary_success
  @secondary_success
end

#successFixnum

The number of units that succeeded in the operation. Corresponds to the JSON property success

Returns:

  • (Fixnum)


4954
4955
4956
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4954

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4961
4962
4963
4964
4965
4966
4967
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4961

def update!(**args)
  @failure = args[:failure] if args.key?(:failure)
  @pending = args[:pending] if args.key?(:pending)
  @secondary_failure = args[:secondary_failure] if args.key?(:secondary_failure)
  @secondary_success = args[:secondary_success] if args.key?(:secondary_success)
  @success = args[:success] if args.key?(:success)
end