Class: Google::Apis::HealthcareV1::ProgressCounter
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::ProgressCounter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
ProgressCounter provides counters to describe an operation's progress.
Instance Attribute Summary collapse
-
#failure ⇒ Fixnum
The number of units that failed in the operation.
-
#pending ⇒ Fixnum
The number of units that are pending in the operation.
-
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
-
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
-
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProgressCounter
constructor
A new instance of ProgressCounter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProgressCounter
Returns a new instance of ProgressCounter.
4956 4957 4958 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure ⇒ Fixnum
The number of units that failed in the operation.
Corresponds to the JSON property failure
4934 4935 4936 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4934 def failure @failure end |
#pending ⇒ Fixnum
The number of units that are pending in the operation.
Corresponds to the JSON property pending
4939 4940 4941 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4939 def pending @pending end |
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
Corresponds to the JSON property secondaryFailure
4944 4945 4946 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4944 def secondary_failure @secondary_failure end |
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
Corresponds to the JSON property secondarySuccess
4949 4950 4951 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4949 def secondary_success @secondary_success end |
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Corresponds to the JSON property success
4954 4955 4956 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4954 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4961 4962 4963 4964 4965 4966 4967 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4961 def update!(**args) @failure = args[:failure] if args.key?(:failure) @pending = args[:pending] if args.key?(:pending) @secondary_failure = args[:secondary_failure] if args.key?(:secondary_failure) @secondary_success = args[:secondary_success] if args.key?(:secondary_success) @success = args[:success] if args.key?(:success) end |