Class: Google::Apis::HealthcareV1::ProgressCounter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

ProgressCounter provides counters to describe an operation's progress.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProgressCounter

Returns a new instance of ProgressCounter.



4837
4838
4839
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failureFixnum

The number of units that failed in the operation. Corresponds to the JSON property failure

Returns:

  • (Fixnum)


4825
4826
4827
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4825

def failure
  @failure
end

#pendingFixnum

The number of units that are pending in the operation. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


4830
4831
4832
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4830

def pending
  @pending
end

#successFixnum

The number of units that succeeded in the operation. Corresponds to the JSON property success

Returns:

  • (Fixnum)


4835
4836
4837
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4835

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4842
4843
4844
4845
4846
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4842

def update!(**args)
  @failure = args[:failure] if args.key?(:failure)
  @pending = args[:pending] if args.key?(:pending)
  @success = args[:success] if args.key?(:success)
end