Class: Google::Apis::HealthcareV1::QueryAccessibleDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::QueryAccessibleDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Queries all data_ids that are consented for a given use in the given consent store and writes them to a specified destination. The returned Operation includes a progress counter for the number of User data mappings processed. Errors are logged to Cloud Logging (see Viewing error logs in Cloud Logging and [ QueryAccessibleData] for a sample log entry).
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1ConsentGcsDestination
The Cloud Storage location for export.
-
#request_attributes ⇒ Hash<String,String>
The values of request attributes associated with this access request.
-
#resource_attributes ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryAccessibleDataRequest
constructor
A new instance of QueryAccessibleDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryAccessibleDataRequest
Returns a new instance of QueryAccessibleDataRequest.
5026 5027 5028 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1ConsentGcsDestination
The Cloud Storage location for export.
Corresponds to the JSON property gcsDestination
5012 5013 5014 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5012 def gcs_destination @gcs_destination end |
#request_attributes ⇒ Hash<String,String>
The values of request attributes associated with this access request.
Corresponds to the JSON property requestAttributes
5017 5018 5019 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5017 def request_attributes @request_attributes end |
#resource_attributes ⇒ Hash<String,String>
Optional. The values of resource attributes associated with the type of
resources being requested. If no values are specified, then all resource types
are included in the output.
Corresponds to the JSON property resourceAttributes
5024 5025 5026 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5024 def resource_attributes @resource_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5031 5032 5033 5034 5035 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5031 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @request_attributes = args[:request_attributes] if args.key?(:request_attributes) @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes) end |