Class: Google::Apis::HealthcareV1::QueryAccessibleDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::QueryAccessibleDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Queries all data_ids that are consented for a given use in the given consent store and writes them to a specified destination. The returned Operation includes a progress counter for the number of User data mappings processed. Errors are logged to Cloud Logging (see Viewing error logs in Cloud Logging and [ QueryAccessibleData] for a sample log entry).
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1ConsentGcsDestination
The Cloud Storage location for export.
-
#request_attributes ⇒ Hash<String,String>
The values of request attributes associated with this access request.
-
#resource_attributes ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryAccessibleDataRequest
constructor
A new instance of QueryAccessibleDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryAccessibleDataRequest
Returns a new instance of QueryAccessibleDataRequest.
4905 4906 4907 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::HealthcareV1::GoogleCloudHealthcareV1ConsentGcsDestination
The Cloud Storage location for export.
Corresponds to the JSON property gcsDestination
4891 4892 4893 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4891 def gcs_destination @gcs_destination end |
#request_attributes ⇒ Hash<String,String>
The values of request attributes associated with this access request.
Corresponds to the JSON property requestAttributes
4896 4897 4898 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4896 def request_attributes @request_attributes end |
#resource_attributes ⇒ Hash<String,String>
Optional. The values of resource attributes associated with the type of
resources being requested. If no values are specified, then all resource types
are included in the output.
Corresponds to the JSON property resourceAttributes
4903 4904 4905 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4903 def resource_attributes @resource_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4910 4911 4912 4913 4914 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 4910 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @request_attributes = args[:request_attributes] if args.key?(:request_attributes) @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes) end |