Class: Google::Apis::HealthcareV1::RollbackFhirResourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::RollbackFhirResourcesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Instance Attribute Summary collapse
-
#change_type ⇒ String
Optional.
-
#exclude_rollbacks ⇒ Boolean
(also: #exclude_rollbacks?)
Optional.
-
#filtering_fields ⇒ Google::Apis::HealthcareV1::RollbackFhirResourceFilteringFields
Optional.
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#input_gcs_object ⇒ String
Optional.
-
#result_gcs_bucket ⇒ String
Required.
-
#rollback_time ⇒ String
Required.
-
#type ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollbackFhirResourcesRequest
constructor
A new instance of RollbackFhirResourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollbackFhirResourcesRequest
Returns a new instance of RollbackFhirResourcesRequest.
5144 5145 5146 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#change_type ⇒ String
Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type.
Corresponds to the JSON property changeType
5104 5105 5106 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5104 def change_type @change_type end |
#exclude_rollbacks ⇒ Boolean Also known as: exclude_rollbacks?
Optional. Specifies whether to exclude earlier rollbacks.
Corresponds to the JSON property excludeRollbacks
5109 5110 5111 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5109 def exclude_rollbacks @exclude_rollbacks end |
#filtering_fields ⇒ Google::Apis::HealthcareV1::RollbackFhirResourceFilteringFields
Optional. Parameters for filtering resources
Corresponds to the JSON property filteringFields
5115 5116 5117 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5115 def filtering_fields @filtering_fields end |
#force ⇒ Boolean Also known as: force?
Optional. When enabled, changes will be reverted without explicit confirmation
Corresponds to the JSON property force
5120 5121 5122 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5120 def force @force end |
#input_gcs_object ⇒ String
Optional. Cloud Storage object containing list of resourceType/resourceId
lines, identifying resources to be reverted
Corresponds to the JSON property inputGcsObject
5127 5128 5129 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5127 def input_gcs_object @input_gcs_object end |
#result_gcs_bucket ⇒ String
Required. Bucket to deposit result
Corresponds to the JSON property resultGcsBucket
5132 5133 5134 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5132 def result_gcs_bucket @result_gcs_bucket end |
#rollback_time ⇒ String
Required. Time point to rollback to.
Corresponds to the JSON property rollbackTime
5137 5138 5139 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5137 def rollback_time @rollback_time end |
#type ⇒ Array<String>
Optional. If specified, revert only resources of these types
Corresponds to the JSON property type
5142 5143 5144 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5142 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5149 def update!(**args) @change_type = args[:change_type] if args.key?(:change_type) @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks) @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields) @force = args[:force] if args.key?(:force) @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object) @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket) @rollback_time = args[:rollback_time] if args.key?(:rollback_time) @type = args[:type] if args.key?(:type) end |