Class: Google::Apis::HealthcareV1::RollbackHl7V2MessagesRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::RollbackHl7V2MessagesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
Point in time recovery rollback request.
Instance Attribute Summary collapse
-
#change_type ⇒ String
Optional.
-
#exclude_rollbacks ⇒ Boolean
(also: #exclude_rollbacks?)
Optional.
-
#filtering_fields ⇒ Google::Apis::HealthcareV1::RollbackHl7MessagesFilteringFields
Filtering fields for an HL7v2 rollback.
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#input_gcs_object ⇒ String
Optional.
-
#result_gcs_bucket ⇒ String
Required.
-
#rollback_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollbackHl7V2MessagesRequest
constructor
A new instance of RollbackHl7V2MessagesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollbackHl7V2MessagesRequest
Returns a new instance of RollbackHl7V2MessagesRequest.
5244 5245 5246 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#change_type ⇒ String
Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type.
Corresponds to the JSON property changeType
5208 5209 5210 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5208 def change_type @change_type end |
#exclude_rollbacks ⇒ Boolean Also known as: exclude_rollbacks?
Optional. Specifies whether to exclude earlier rollbacks.
Corresponds to the JSON property excludeRollbacks
5213 5214 5215 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5213 def exclude_rollbacks @exclude_rollbacks end |
#filtering_fields ⇒ Google::Apis::HealthcareV1::RollbackHl7MessagesFilteringFields
Filtering fields for an HL7v2 rollback. Currently only supports a list of
operation ids to roll back.
Corresponds to the JSON property filteringFields
5220 5221 5222 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5220 def filtering_fields @filtering_fields end |
#force ⇒ Boolean Also known as: force?
Optional. When enabled, changes will be reverted without explicit confirmation.
Corresponds to the JSON property force
5225 5226 5227 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5225 def force @force end |
#input_gcs_object ⇒ String
Optional. Cloud storage object containing list of resourceId lines,
identifying resources to be reverted
Corresponds to the JSON property inputGcsObject
5232 5233 5234 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5232 def input_gcs_object @input_gcs_object end |
#result_gcs_bucket ⇒ String
Required. Bucket to deposit result
Corresponds to the JSON property resultGcsBucket
5237 5238 5239 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5237 def result_gcs_bucket @result_gcs_bucket end |
#rollback_time ⇒ String
Required. Times point to rollback to.
Corresponds to the JSON property rollbackTime
5242 5243 5244 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5242 def rollback_time @rollback_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5249 5250 5251 5252 5253 5254 5255 5256 5257 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5249 def update!(**args) @change_type = args[:change_type] if args.key?(:change_type) @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks) @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields) @force = args[:force] if args.key?(:force) @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object) @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket) @rollback_time = args[:rollback_time] if args.key?(:rollback_time) end |