Class: Google::Apis::HealthcareV1::SchemaPackage
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1::SchemaPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb
Overview
A schema package contains a set of schemas and type definitions.
Instance Attribute Summary collapse
-
#ignore_min_occurs ⇒ Boolean
(also: #ignore_min_occurs?)
Optional.
-
#schemas ⇒ Array<Google::Apis::HealthcareV1::Hl7SchemaConfig>
Optional.
-
#schematized_parsing_type ⇒ String
Optional.
-
#types ⇒ Array<Google::Apis::HealthcareV1::Hl7TypesConfig>
Optional.
-
#unexpected_segment_handling ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaPackage
constructor
A new instance of SchemaPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaPackage
Returns a new instance of SchemaPackage.
5565 5566 5567 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ignore_min_occurs ⇒ Boolean Also known as: ignore_min_occurs?
Optional. Flag to ignore all min_occurs restrictions in the schema. This means
that incoming messages can omit any group, segment, field, component, or
subcomponent.
Corresponds to the JSON property ignoreMinOccurs
5535 5536 5537 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5535 def ignore_min_occurs @ignore_min_occurs end |
#schemas ⇒ Array<Google::Apis::HealthcareV1::Hl7SchemaConfig>
Optional. Schema configs that are layered based on their VersionSources that
match the incoming message. Schema configs present in higher indices override
those in lower indices with the same message type and trigger event if their
VersionSources all match an incoming message.
Corresponds to the JSON property schemas
5544 5545 5546 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5544 def schemas @schemas end |
#schematized_parsing_type ⇒ String
Optional. Determines how messages that fail to parse are handled.
Corresponds to the JSON property schematizedParsingType
5549 5550 5551 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5549 def schematized_parsing_type @schematized_parsing_type end |
#types ⇒ Array<Google::Apis::HealthcareV1::Hl7TypesConfig>
Optional. Schema type definitions that are layered based on their
VersionSources that match the incoming message. Type definitions present in
higher indices override those in lower indices with the same type name if
their VersionSources all match an incoming message.
Corresponds to the JSON property types
5557 5558 5559 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5557 def types @types end |
#unexpected_segment_handling ⇒ String
Optional. Determines how unexpected segments (segments not matched to the
schema) are handled.
Corresponds to the JSON property unexpectedSegmentHandling
5563 5564 5565 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5563 def unexpected_segment_handling @unexpected_segment_handling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5570 5571 5572 5573 5574 5575 5576 |
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5570 def update!(**args) @ignore_min_occurs = args[:ignore_min_occurs] if args.key?(:ignore_min_occurs) @schemas = args[:schemas] if args.key?(:schemas) @schematized_parsing_type = args[:schematized_parsing_type] if args.key?(:schematized_parsing_type) @types = args[:types] if args.key?(:types) @unexpected_segment_handling = args[:unexpected_segment_handling] if args.key?(:unexpected_segment_handling) end |