Class: Google::Apis::HealthcareV1::SchemaPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

A schema package contains a set of schemas and type definitions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaPackage

Returns a new instance of SchemaPackage.



5402
5403
5404
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ignore_min_occursBoolean Also known as: ignore_min_occurs?

Optional. Flag to ignore all min_occurs restrictions in the schema. This means that incoming messages can omit any group, segment, field, component, or subcomponent. Corresponds to the JSON property ignoreMinOccurs

Returns:

  • (Boolean)


5372
5373
5374
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5372

def ignore_min_occurs
  @ignore_min_occurs
end

#schemasArray<Google::Apis::HealthcareV1::Hl7SchemaConfig>

Optional. Schema configs that are layered based on their VersionSources that match the incoming message. Schema configs present in higher indices override those in lower indices with the same message type and trigger event if their VersionSources all match an incoming message. Corresponds to the JSON property schemas



5381
5382
5383
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5381

def schemas
  @schemas
end

#schematized_parsing_typeString

Optional. Determines how messages that fail to parse are handled. Corresponds to the JSON property schematizedParsingType

Returns:

  • (String)


5386
5387
5388
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5386

def schematized_parsing_type
  @schematized_parsing_type
end

#typesArray<Google::Apis::HealthcareV1::Hl7TypesConfig>

Optional. Schema type definitions that are layered based on their VersionSources that match the incoming message. Type definitions present in higher indices override those in lower indices with the same type name if their VersionSources all match an incoming message. Corresponds to the JSON property types



5394
5395
5396
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5394

def types
  @types
end

#unexpected_segment_handlingString

Optional. Determines how unexpected segments (segments not matched to the schema) are handled. Corresponds to the JSON property unexpectedSegmentHandling

Returns:

  • (String)


5400
5401
5402
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5400

def unexpected_segment_handling
  @unexpected_segment_handling
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5407
5408
5409
5410
5411
5412
5413
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5407

def update!(**args)
  @ignore_min_occurs = args[:ignore_min_occurs] if args.key?(:ignore_min_occurs)
  @schemas = args[:schemas] if args.key?(:schemas)
  @schematized_parsing_type = args[:schematized_parsing_type] if args.key?(:schematized_parsing_type)
  @types = args[:types] if args.key?(:types)
  @unexpected_segment_handling = args[:unexpected_segment_handling] if args.key?(:unexpected_segment_handling)
end