Class: Google::Apis::HealthcareV1::SchemaSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

An HL7v2 Segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaSegment

Returns a new instance of SchemaSegment.



5436
5437
5438
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_occursFixnum

The maximum number of times this segment can be present in this group. 0 or -1 means unbounded. Corresponds to the JSON property maxOccurs

Returns:

  • (Fixnum)


5424
5425
5426
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5424

def max_occurs
  @max_occurs
end

#min_occursFixnum

The minimum number of times this segment can be present in this group. Corresponds to the JSON property minOccurs

Returns:

  • (Fixnum)


5429
5430
5431
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5429

def min_occurs
  @min_occurs
end

#typeString

The Segment type. For example, "PID". Corresponds to the JSON property type

Returns:

  • (String)


5434
5435
5436
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5434

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5441
5442
5443
5444
5445
# File 'lib/google/apis/healthcare_v1/classes.rb', line 5441

def update!(**args)
  @max_occurs = args[:max_occurs] if args.key?(:max_occurs)
  @min_occurs = args[:min_occurs] if args.key?(:min_occurs)
  @type = args[:type] if args.key?(:type)
end