Class: Google::Apis::HealthcareV1::TimeRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1/classes.rb,
lib/google/apis/healthcare_v1/representations.rb,
lib/google/apis/healthcare_v1/representations.rb

Overview

Apply consents given by patients whose most recent consent changes are in the time range. Note that after identifying these patients, the server applies all Consent resources given by those patients, not just the Consent resources within the timestamp in the range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeRange

Returns a new instance of TimeRange.



6185
6186
6187
# File 'lib/google/apis/healthcare_v1/classes.rb', line 6185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

Optional. The latest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+zz: zz If not specified, the system uses the time when ApplyConsents was called. Corresponds to the JSON property end

Returns:

  • (String)


6177
6178
6179
# File 'lib/google/apis/healthcare_v1/classes.rb', line 6177

def end
  @end
end

#startString

Optional. The earliest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+ zz:zz If not specified, the system uses the FHIR store creation time. Corresponds to the JSON property start

Returns:

  • (String)


6183
6184
6185
# File 'lib/google/apis/healthcare_v1/classes.rb', line 6183

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6190
6191
6192
6193
# File 'lib/google/apis/healthcare_v1/classes.rb', line 6190

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end